@@ -1,5 +1,4 @@
 //go:build !remote
-// +build !remote
 
 package libimage
 
@@ -17,8 +16,7 @@ import (
 
 func TestCorruptedLayers(t *testing.T) {
 	// Regression tests for https://bugzilla.redhat.com/show_bug.cgi?id=1966872.
-	runtime, cleanup := testNewRuntime(t)
-	defer cleanup()
+	runtime := testNewRuntime(t)
 	ctx := context.Background()
 	pullOptions := &PullOptions{}
 	pullOptions.Writer = os.Stdout
@@ -34,7 +32,7 @@ func TestCorruptedLayers(t *testing.T) {
 	require.Len(t, pulledImages, 1)
 	image := pulledImages[0]
 
-	// Inpsecting a healthy image should work.
+	// Inspecting a healthy image should work.
 	_, err = image.Inspect(ctx, nil)
 	require.NoError(t, err, "inspecting healthy image should work")
 
@@ -70,7 +68,7 @@ func TestCorruptedLayers(t *testing.T) {
 	_, err = image.Inspect(ctx, nil)
 	require.Error(t, err, "inspecting corrupted image should fail")
 
-	err = image.isCorrupted(imageName)
+	err = image.isCorrupted(ctx, imageName)
 	require.Error(t, err, "image is corrupted")
 
 	exists, err = runtime.Exists(imageName)
