@@ -1,5 +1,4 @@
 //go:build !remote
-// +build !remote
 
 package libimage
 
@@ -23,8 +22,7 @@ func TestImageFunctions(t *testing.T) {
 	busyboxLatest := busybox + ":latest"
 	busyboxDigest := busybox + "@"
 
-	runtime, cleanup := testNewRuntime(t)
-	defer cleanup()
+	runtime := testNewRuntime(t)
 	ctx := context.Background()
 
 	// Looking up image by invalid sha.
@@ -71,7 +69,7 @@ func TestImageFunctions(t *testing.T) {
 	// manifest list we chose it from.
 	digests := image.Digests()
 	require.Len(t, digests, 2)
-	require.Equal(t, origDigest.String(), digests[0].String(), "first recoreded digest should be the one of the image")
+	require.Equal(t, origDigest.String(), digests[0].String(), "first recorded digest should be the one of the image")
 
 	// containers/podman/issues/12729: make sure manifest lookup returns
 	// the correct error for both digests.
@@ -191,8 +189,7 @@ func TestLookupImage(t *testing.T) {
 	alpineNoTag := "quay.io/libpod/alpine"
 	alpineLatest := alpineNoTag + ":latest"
 
-	runtime, cleanup := testNewRuntime(t)
-	defer cleanup()
+	runtime := testNewRuntime(t)
 	ctx := context.Background()
 
 	pullOptions := &PullOptions{}
@@ -246,8 +243,7 @@ func TestLookupImage(t *testing.T) {
 }
 
 func TestInspectHealthcheck(t *testing.T) {
-	runtime, cleanup := testNewRuntime(t)
-	defer cleanup()
+	runtime := testNewRuntime(t)
 	ctx := context.Background()
 
 	imageName := "quay.io/libpod/healthcheck:config-only"
@@ -266,8 +262,7 @@ func TestInspectHealthcheck(t *testing.T) {
 }
 
 func TestTag(t *testing.T) {
-	runtime, image, cleanup := getImageAndRuntime(t)
-	defer cleanup()
+	runtime, image := getImageAndRuntime(t)
 
 	digest := "sha256:adab3844f497ab9171f070d4cae4114b5aec565ac772e2f2579405b78be67c96"
 
@@ -304,8 +299,7 @@ func TestTag(t *testing.T) {
 }
 
 func TestTagAndUntagParallel(t *testing.T) {
-	runtime, image, cleanup := getImageAndRuntime(t)
-	defer cleanup()
+	runtime, image := getImageAndRuntime(t)
 
 	tagCount := 10
 	wg := sync.WaitGroup{}
@@ -317,7 +311,7 @@ func TestTagAndUntagParallel(t *testing.T) {
 
 	// Test tag in parallel, the extra go routine is critical for the test do not remove that.
 	wg.Add(tagCount)
-	for i := 0; i < tagCount; i++ {
+	for i := range tagCount {
 		name := fmt.Sprintf("localhost/tag-%d:latest", i)
 		names = append(names, name)
 		go func(name string) {
@@ -337,7 +331,7 @@ func TestTagAndUntagParallel(t *testing.T) {
 
 	// Test untag in parallel
 	wg.Add(tagCount)
-	for i := 0; i < tagCount; i++ {
+	for i := range tagCount {
 		name := fmt.Sprintf("localhost/tag-%d:latest", i)
 		names = append(names, name)
 		go func(name string) {
@@ -355,8 +349,7 @@ func TestTagAndUntagParallel(t *testing.T) {
 }
 
 func TestUntag(t *testing.T) {
-	runtime, image, cleanup := getImageAndRuntime(t)
-	defer cleanup()
+	runtime, image := getImageAndRuntime(t)
 
 	digest := "sha256:adab3844f497ab9171f070d4cae4114b5aec565ac772e2f2579405b78be67c96"
 
@@ -385,7 +378,7 @@ func TestUntag(t *testing.T) {
 			require.EqualError(t, err, test.expectError, "untag should have failed: %v", test)
 			continue
 		}
-		require.NoError(t, err, "untag should have succeedded: %v", test)
+		require.NoError(t, err, "untag should have succeeded: %v", test)
 		_, resolvedName, err := runtime.LookupImage(test.tag, nil)
 		require.Error(t, err, "image should not resolve after untag anymore (%s): %v", resolvedName, test)
 	}
@@ -395,12 +388,12 @@ func TestUntag(t *testing.T) {
 	require.ErrorIs(t, err, errUntagDigest, "check for specific digest error")
 }
 
-func getImageAndRuntime(t *testing.T) (*Runtime, *Image, func()) {
+func getImageAndRuntime(t *testing.T) (*Runtime, *Image) {
 	// Note: this will resolve pull from the GCR registry (see
 	// testdata/registries.conf).
-	busyboxLatest := "docker.io/library/busybox:latest"
+	busyboxLatest := "quay.io/libpod/busybox:latest"
 
-	runtime, cleanup := testNewRuntime(t)
+	runtime := testNewRuntime(t)
 	ctx := context.Background()
 
 	pullOptions := &PullOptions{}
@@ -411,5 +404,5 @@ func getImageAndRuntime(t *testing.T) (*Runtime, *Image, func()) {
 
 	image := pulledImages[0]
 
-	return runtime, image, cleanup
+	return runtime, image
 }
