@@ -1,9 +1,9 @@
 //go:build !remote
-// +build !remote
 
 package libimage
 
 import (
+	"context"
 	"os"
 	"testing"
 
@@ -11,6 +11,7 @@ import (
 	"github.com/containers/image/v5/types"
 	"github.com/containers/storage"
 	"github.com/containers/storage/pkg/reexec"
+	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
 
@@ -25,12 +26,9 @@ type testNewRuntimeOptions struct {
 	registriesConfPath string
 }
 
-// Create a new Runtime that can be used for testing.  The second return value
-// is a clean-up function that should be called by users to make sure all
-// temporary test data gets removed.
-func testNewRuntime(t *testing.T, options ...testNewRuntimeOptions) (runtime *Runtime, cleanup func()) {
-	workdir, err := os.MkdirTemp("", "testStorageRuntime")
-	require.NoError(t, err)
+// Create a new Runtime that can be used for testing.
+func testNewRuntime(t *testing.T, options ...testNewRuntimeOptions) *Runtime {
+	workdir := t.TempDir()
 	storeOptions := &storage.StoreOptions{
 		RunRoot:         workdir,
 		GraphRoot:       workdir,
@@ -47,20 +45,24 @@ func testNewRuntime(t *testing.T, options ...testNewRuntimeOptions) (runtime *Ru
 		systemContext.SystemRegistriesConfPath = options[0].registriesConfPath
 	}
 
-	runtime, err = RuntimeFromStoreOptions(&RuntimeOptions{SystemContext: systemContext}, storeOptions)
+	runtime, err := RuntimeFromStoreOptions(&RuntimeOptions{SystemContext: systemContext}, storeOptions)
 	require.NoError(t, err)
 	tmpd, err := tmpdir()
 	require.NoError(t, err)
 	require.Equal(t, runtime.systemContext.BigFilesTemporaryDir, tmpd)
 
-	cleanup = func() {
-		_ = runtime.Shutdown(true)
-		_ = os.RemoveAll(workdir)
-	}
+	t.Cleanup(func() { _ = runtime.Shutdown(true) })
 
 	sys := runtime.SystemContext()
 	require.NotNil(t, sys)
-	return runtime, cleanup
+	return runtime
+}
+
+func testRuntimePullImage(t *testing.T, r *Runtime, ctx context.Context, imageName string) {
+	pullOptions := &PullOptions{}
+	pullOptions.Writer = os.Stdout
+	_, err := r.Pull(ctx, imageName, config.PullPolicyMissing, pullOptions)
+	require.NoError(t, err)
 }
 
 func TestTmpdir(t *testing.T) {
@@ -101,3 +103,49 @@ func TestTmpdir(t *testing.T) {
 		os.Unsetenv(tmpStr)
 	}
 }
+
+func TestRuntimeListImagesAllImages(t *testing.T) {
+	runtime := testNewRuntime(t)
+	ctx := context.Background()
+
+	// Prefetch alpine, busybox.
+	testRuntimePullImage(t, runtime, ctx, "quay.io/libpod/alpine:latest")
+	testRuntimePullImage(t, runtime, ctx, "quay.io/libpod/busybox:latest")
+
+	images, err := runtime.ListImages(ctx, nil)
+	require.NoError(t, err)
+
+	require.Len(t, images, 2)
+	var image_names []string
+	for _, i := range images {
+		image_names = append(image_names, i.Names()...)
+	}
+	assert.ElementsMatch(t,
+		image_names,
+		[]string{"quay.io/libpod/alpine:latest", "quay.io/libpod/busybox:latest"},
+	)
+}
+
+func TestRuntimeListImagesByNames(t *testing.T) {
+	runtime := testNewRuntime(t)
+	ctx := context.Background()
+
+	// Prefetch alpine, busybox.
+	testRuntimePullImage(t, runtime, ctx, "quay.io/libpod/alpine:latest")
+	testRuntimePullImage(t, runtime, ctx, "quay.io/libpod/busybox:latest")
+
+	for _, test := range []struct {
+		name     string
+		fullName string
+	}{
+		{"alpine", "quay.io/libpod/alpine:latest"},
+		{"busybox", "quay.io/libpod/busybox:latest"},
+	} {
+		images, err := runtime.ListImagesByNames([]string{test.name})
+		require.NoError(t, err)
+		require.Len(t, images, 1)
+		require.Contains(t, images[0].Names(), test.fullName)
+	}
+	_, err := runtime.ListImagesByNames([]string{""})
+	require.Error(t, err)
+}
