@@ -1,5 +1,4 @@
 //go:build !remote
-// +build !remote
 
 package libimage
 
@@ -14,16 +13,15 @@ import (
 )
 
 func TestSave(t *testing.T) {
-	runtime, cleanup := testNewRuntime(t)
-	defer cleanup()
+	runtime := testNewRuntime(t)
 	ctx := context.Background()
 
 	// Prefetch alpine, busybox.
 	pullOptions := &PullOptions{}
 	pullOptions.Writer = os.Stdout
-	_, err := runtime.Pull(ctx, "docker.io/library/alpine:latest", config.PullPolicyAlways, pullOptions)
+	_, err := runtime.Pull(ctx, "quay.io/libpod/alpine:latest", config.PullPolicyAlways, pullOptions)
 	require.NoError(t, err)
-	_, err = runtime.Pull(ctx, "docker.io/library/busybox:latest", config.PullPolicyAlways, pullOptions)
+	_, err = runtime.Pull(ctx, "quay.io/libpod/busybox:latest", config.PullPolicyAlways, pullOptions)
 	require.NoError(t, err)
 
 	// Save the two images into a multi-image archive.  This way, we can
@@ -74,9 +72,7 @@ func TestSave(t *testing.T) {
 		_, err = runtime.Load(ctx, imageCache.Name(), loadOptions)
 		require.NoError(t, err)
 
-		tmp, err := os.MkdirTemp("", "libimagesavetest")
-		require.NoError(t, err)
-		defer os.RemoveAll(tmp)
+		tmp := t.TempDir()
 		if !test.isDir {
 			tmp += "/archive.tar"
 		}
@@ -105,7 +101,7 @@ func TestSave(t *testing.T) {
 		if strings.HasSuffix(test.format, "-dir") {
 			continue
 		}
-		_, err = runtime.ListImages(ctx, namesAndTags, nil)
+		_, err = runtime.ListImagesByNames(namesAndTags)
 		require.NoError(t, err, "%v", test)
 	}
 }
