@@ -1,5 +1,4 @@
-//go:build linux
-// +build linux
+//go:build (linux || freebsd) && cni
 
 package cni_test
 
@@ -53,7 +52,7 @@ var _ = Describe("Config", func() {
 	Context("basic network config tests", func() {
 		It("check default network config exists", func() {
 			networks, err := libpodNet.NetworkList()
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(1))
 			Expect(networks[0].Name).To(Equal("podman"))
 			Expect(networks[0].Driver).To(Equal("bridge"))
@@ -76,7 +75,7 @@ var _ = Describe("Config", func() {
 			now := time.Now().Add(-500 * time.Millisecond)
 			network := types.Network{}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			path := filepath.Join(cniConfDir, network1.Name+".conflist")
 			Expect(path).To(BeARegularFile())
@@ -97,29 +96,29 @@ var _ = Describe("Config", func() {
 
 			// inspect by name
 			network2, err := libpodNet.NetworkInspect(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network2).To(Equal(network1))
 
 			// inspect by ID
 			network2, err = libpodNet.NetworkInspect(network1.ID)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network2).To(Equal(network1))
 
 			// inspect by partial ID
 			network2, err = libpodNet.NetworkInspect(network1.ID[:10])
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network2).To(Equal(network1))
 
 			// create a new interface to force a config load from disk
 			libpodNet, err = getNetworkInterface(cniConfDir)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			network2, err = libpodNet.NetworkInspect(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network2).To(Equal(network1))
 
 			err = libpodNet.NetworkRemove(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(path).ToNot(BeARegularFile())
 
 			_, err = libpodNet.NetworkInspect(network1.Name)
@@ -134,13 +133,13 @@ var _ = Describe("Config", func() {
 
 			network := types.Network{}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.Subnets).To(HaveLen(1))
 
 			network = types.Network{}
 			network2, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network2.Name).ToNot(Equal(network1.Name))
 			Expect(network2.ID).ToNot(Equal(network1.ID))
 			Expect(network2.NetworkInterface).ToNot(Equal(network1.NetworkInterface))
@@ -151,7 +150,7 @@ var _ = Describe("Config", func() {
 		It("fail when creating two networks with the same name", func() {
 			network := types.Network{}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.Subnets).To(HaveLen(1))
 
@@ -163,13 +162,13 @@ var _ = Describe("Config", func() {
 		It("return the same network when creating two networks with the same name and ignore", func() {
 			network := types.Network{}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.Subnets).To(HaveLen(1))
 
 			network = types.Network{Name: network1.Name}
 			network2, err := libpodNet.NetworkCreate(network, &types.NetworkCreateOptions{IgnoreIfExists: true})
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network2).To(Equal(network1))
 		})
 
@@ -186,7 +185,7 @@ var _ = Describe("Config", func() {
 		It("create bridge config", func() {
 			network := types.Network{Driver: "bridge"}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(filepath.Join(cniConfDir, network1.Name+".conflist")).To(BeARegularFile())
 			Expect(network1.ID).ToNot(BeEmpty())
@@ -212,7 +211,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(filepath.Join(cniConfDir, network1.Name+".conflist")).To(BeARegularFile())
 			Expect(network1.ID).ToNot(BeEmpty())
@@ -239,19 +238,19 @@ var _ = Describe("Config", func() {
 				DNSEnabled: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.DNSEnabled).To(BeFalse())
 			Expect(network1.IPAMOptions).ToNot(BeEmpty())
 			Expect(network1.IPAMOptions).To(HaveKeyWithValue("driver", "none"))
-			Expect(network1.Subnets).To(HaveLen(0))
+			Expect(network1.Subnets).To(BeEmpty())
 
 			// reload configs from disk
 			libpodNet, err = getNetworkInterface(cniConfDir)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			network2, err := libpodNet.NetworkInspect(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network2).To(Equal(network1))
 		})
 
@@ -280,18 +279,18 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.IPAMOptions).ToNot(BeEmpty())
 			Expect(network1.IPAMOptions).To(HaveKeyWithValue("driver", "dhcp"))
-			Expect(network1.Subnets).To(HaveLen(0))
+			Expect(network1.Subnets).To(BeEmpty())
 
 			// reload configs from disk
 			libpodNet, err = getNetworkInterface(cniConfDir)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			network2, err := libpodNet.NetworkInspect(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network2).To(Equal(network1))
 		})
 
@@ -318,7 +317,7 @@ var _ = Describe("Config", func() {
 				NetworkInterface: "cni-podman2",
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).To(Equal("cni-podman2"))
@@ -332,7 +331,7 @@ var _ = Describe("Config", func() {
 		It("create macvlan config", func() {
 			network := types.Network{Driver: "macvlan"}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(filepath.Join(cniConfDir, network1.Name+".conflist")).To(BeARegularFile())
 			Expect(network1.ID).ToNot(BeEmpty())
@@ -341,7 +340,7 @@ var _ = Describe("Config", func() {
 			Expect(network1.Options).To(BeEmpty())
 			Expect(network1.IPAMOptions).ToNot(BeEmpty())
 			Expect(network1.IPAMOptions).To(HaveKeyWithValue("driver", "dhcp"))
-			Expect(network1.Subnets).To(HaveLen(0))
+			Expect(network1.Subnets).To(BeEmpty())
 			Expect(network1.DNSEnabled).To(BeFalse())
 			Expect(network1.Internal).To(BeFalse())
 		})
@@ -352,7 +351,7 @@ var _ = Describe("Config", func() {
 				NetworkInterface: "lo",
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			path := filepath.Join(cniConfDir, network1.Name+".conflist")
 			Expect(path).To(BeARegularFile())
@@ -360,7 +359,7 @@ var _ = Describe("Config", func() {
 			Expect(network1.Driver).To(Equal("macvlan"))
 			Expect(network1.Labels).To(BeEmpty())
 			Expect(network1.Options).To(BeEmpty())
-			Expect(network1.Subnets).To(HaveLen(0))
+			Expect(network1.Subnets).To(BeEmpty())
 			Expect(network1.DNSEnabled).To(BeFalse())
 			Expect(network1.Internal).To(BeFalse())
 			Expect(network1.IPAMOptions).To(HaveKeyWithValue("driver", "dhcp"))
@@ -379,7 +378,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			path := filepath.Join(cniConfDir, network1.Name+".conflist")
 			Expect(path).To(BeARegularFile())
@@ -408,7 +407,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			path := filepath.Join(cniConfDir, network1.Name+".conflist")
 			Expect(path).To(BeARegularFile())
@@ -431,7 +430,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			path := filepath.Join(cniConfDir, network1.Name+".conflist")
 			Expect(path).To(BeARegularFile())
@@ -458,7 +457,7 @@ var _ = Describe("Config", func() {
 					},
 				}
 				network1, err := libpodNet.NetworkCreate(network, nil)
-				Expect(err).To(BeNil())
+				Expect(err).ToNot(HaveOccurred())
 				Expect(network1.Name).ToNot(BeEmpty())
 				path := filepath.Join(cniConfDir, network1.Name+".conflist")
 				Expect(path).To(BeARegularFile())
@@ -504,7 +503,7 @@ var _ = Describe("Config", func() {
 			}
 			net1, err := libpodNet.NetworkCreate(network, nil)
 			Expect(err).ToNot(HaveOccurred())
-			Expect(net1.Internal).To(Equal(true))
+			Expect(net1.Internal).To(BeTrue())
 			path := filepath.Join(cniConfDir, net1.Name+".conflist")
 			Expect(path).To(BeARegularFile())
 			grepNotFile(path, `"0.0.0.0/0"`)
@@ -521,7 +520,6 @@ var _ = Describe("Config", func() {
 		})
 
 		for _, driver := range []string{"macvlan", "ipvlan"} {
-			driver := driver
 			It(fmt.Sprintf("create %s config with none ipam driver", driver), func() {
 				network := types.Network{
 					Driver: driver,
@@ -530,17 +528,17 @@ var _ = Describe("Config", func() {
 					},
 				}
 				network1, err := libpodNet.NetworkCreate(network, nil)
-				Expect(err).To(BeNil())
+				Expect(err).ToNot(HaveOccurred())
 				Expect(network1.Driver).To(Equal(driver))
 				Expect(network1.IPAMOptions).To(HaveKeyWithValue("driver", "none"))
-				Expect(network1.Subnets).To(HaveLen(0))
+				Expect(network1.Subnets).To(BeEmpty())
 
 				// reload configs from disk
 				libpodNet, err = getNetworkInterface(cniConfDir)
-				Expect(err).To(BeNil())
+				Expect(err).ToNot(HaveOccurred())
 
 				network2, err := libpodNet.NetworkInspect(network1.Name)
-				Expect(err).To(BeNil())
+				Expect(err).ToNot(HaveOccurred())
 				Expect(network2).To(Equal(network1))
 			})
 		}
@@ -554,7 +552,7 @@ var _ = Describe("Config", func() {
 					},
 				}
 				network1, err := libpodNet.NetworkCreate(network, nil)
-				Expect(err).To(BeNil())
+				Expect(err).ToNot(HaveOccurred())
 				Expect(network1.Name).ToNot(BeEmpty())
 				path := filepath.Join(cniConfDir, network1.Name+".conflist")
 				Expect(path).To(BeARegularFile())
@@ -566,10 +564,10 @@ var _ = Describe("Config", func() {
 
 				// reload configs from disk
 				libpodNet, err = getNetworkInterface(cniConfDir)
-				Expect(err).To(BeNil())
+				Expect(err).ToNot(HaveOccurred())
 
 				network2, err := libpodNet.NetworkInspect(network1.Name)
-				Expect(err).To(BeNil())
+				Expect(err).ToNot(HaveOccurred())
 				Expect(network2).To(Equal(network1))
 			}
 		})
@@ -597,7 +595,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -619,7 +617,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -632,10 +630,10 @@ var _ = Describe("Config", func() {
 
 			// reload configs from disk
 			libpodNet, err = getNetworkInterface(cniConfDir)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			// check the networks are identical
 			network2, err := libpodNet.NetworkInspect(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1).To(Equal(network2))
 		})
 
@@ -645,7 +643,7 @@ var _ = Describe("Config", func() {
 				IPv6Enabled: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -671,7 +669,7 @@ var _ = Describe("Config", func() {
 				IPv6Enabled: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -697,7 +695,7 @@ var _ = Describe("Config", func() {
 				IPv6Enabled: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -725,7 +723,7 @@ var _ = Describe("Config", func() {
 				IPv6Enabled: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -753,7 +751,7 @@ var _ = Describe("Config", func() {
 				IPv6Enabled: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -782,7 +780,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -822,7 +820,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -833,7 +831,7 @@ var _ = Describe("Config", func() {
 			Expect(network1.Subnets[0].LeaseRange.StartIP.String()).To(Equal(startIP))
 
 			err = libpodNet.NetworkRemove(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			endIP := "10.0.0.30"
 			network = types.Network{
@@ -845,7 +843,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err = libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(filepath.Join(cniConfDir, network1.Name+".conflist")).To(BeARegularFile())
 			Expect(network1.ID).ToNot(BeEmpty())
@@ -857,7 +855,7 @@ var _ = Describe("Config", func() {
 			Expect(network1.Subnets[0].LeaseRange.EndIP.String()).To(Equal(endIP))
 
 			err = libpodNet.NetworkRemove(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			network = types.Network{
 				Driver: "bridge",
@@ -869,7 +867,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err = libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -882,10 +880,10 @@ var _ = Describe("Config", func() {
 
 			// create a new interface to force a config load from disk
 			libpodNet, err = getNetworkInterface(cniConfDir)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			network1, err = libpodNet.NetworkInspect(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -945,7 +943,7 @@ var _ = Describe("Config", func() {
 				Name: name,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).To(Equal(name))
 			Expect(network1.NetworkInterface).ToNot(Equal(name))
 			Expect(network1.Driver).To(Equal("bridge"))
@@ -966,7 +964,7 @@ var _ = Describe("Config", func() {
 				Name: name,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).To(Equal(name))
 			Expect(network1.NetworkInterface).ToNot(Equal(name))
 			Expect(network1.Driver).To(Equal("bridge"))
@@ -987,7 +985,7 @@ var _ = Describe("Config", func() {
 				NetworkInterface: name,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(Equal(name))
 			Expect(network1.NetworkInterface).To(Equal(name))
 			Expect(network1.Driver).To(Equal("bridge"))
@@ -1025,12 +1023,13 @@ var _ = Describe("Config", func() {
 		})
 
 		It("create bridge with dns", func() {
+			SkipIfNoDnsname()
 			network := types.Network{
 				Driver:     "bridge",
 				DNSEnabled: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.DNSEnabled).To(BeTrue())
 			path := filepath.Join(cniConfDir, network1.Name+".conflist")
@@ -1044,7 +1043,7 @@ var _ = Describe("Config", func() {
 				Internal: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.Subnets).To(HaveLen(1))
 			Expect(network1.Subnets[0].Subnet.String()).ToNot(BeEmpty())
@@ -1062,7 +1061,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.Labels).ToNot(BeNil())
 			Expect(network1.Labels).To(ContainElement("value"))
@@ -1075,7 +1074,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.Options).ToNot(BeNil())
 			path := filepath.Join(cniConfDir, network1.Name+".conflist")
@@ -1111,7 +1110,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.Options).ToNot(BeNil())
 			path := filepath.Join(cniConfDir, network1.Name+".conflist")
@@ -1149,7 +1148,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("macvlan"))
 			Expect(network1.Options).ToNot(BeNil())
 			path := filepath.Join(cniConfDir, network1.Name+".conflist")
@@ -1165,7 +1164,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.Options).ToNot(BeNil())
 			path := filepath.Join(cniConfDir, network1.Name+".conflist")
@@ -1213,13 +1212,14 @@ var _ = Describe("Config", func() {
 		})
 
 		It("network create internal and dns", func() {
+			SkipIfNoDnsname()
 			network := types.Network{
 				Driver:     "bridge",
 				Internal:   true,
 				DNSEnabled: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.Subnets).To(HaveLen(1))
 			Expect(network1.Subnets[0].Subnet.String()).ToNot(BeEmpty())
@@ -1234,11 +1234,11 @@ var _ = Describe("Config", func() {
 		It("network inspect partial ID", func() {
 			network := types.Network{Name: "net4"}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.ID).To(Equal("b44b7426c006839e7fe6f15d1faf64db58079d5233cba09b43be2257c1652cf5"))
 			network = types.Network{Name: "net5"}
 			network1, err = libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.ID).To(Equal("b67e86fb039828ad686aa13667975b9e51f192eb617044faf06cded9d31602af"))
 
 			// Note ID is the sha256 from the name
@@ -1251,7 +1251,7 @@ var _ = Describe("Config", func() {
 		It("network create two with same name", func() {
 			network := types.Network{Name: "net"}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).To(Equal("net"))
 			network = types.Network{Name: "net"}
 			_, err = libpodNet.NetworkCreate(network, nil)
@@ -1265,7 +1265,7 @@ var _ = Describe("Config", func() {
 			Expect(err.Error()).To(Equal("default network podman cannot be removed"))
 
 			network, err := libpodNet.NetworkInspect("podman")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			err = libpodNet.NetworkRemove(network.ID)
 			Expect(err).To(HaveOccurred())
 			Expect(err.Error()).To(Equal("default network podman cannot be removed"))
@@ -1278,7 +1278,7 @@ var _ = Describe("Config", func() {
 			n2, _ := types.ParseCIDR(subnet2)
 			network := types.Network{Subnets: []types.Subnet{{Subnet: n}, {Subnet: n2}}}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Subnets).To(HaveLen(2))
 			network = types.Network{Subnets: []types.Subnet{{Subnet: n}}}
 			_, err = libpodNet.NetworkCreate(network, nil)
@@ -1362,7 +1362,7 @@ var _ = Describe("Config", func() {
 		It("load networks from disk", func() {
 			logrus.SetLevel(logrus.WarnLevel)
 			nets, err := libpodNet.NetworkList()
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(nets).To(HaveLen(numberOfConfigFiles))
 			// test the we do not show logrus warnings/errors
 			logString := logBuffer.String()
@@ -1372,7 +1372,7 @@ var _ = Describe("Config", func() {
 		It("load networks from disk with log level debug", func() {
 			logrus.SetLevel(logrus.DebugLevel)
 			nets, err := libpodNet.NetworkList()
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(nets).To(HaveLen(numberOfConfigFiles))
 			// check for the unsupported ipam plugin message
 			logString := logBuffer.String()
@@ -1382,27 +1382,27 @@ var _ = Describe("Config", func() {
 
 		It("change network struct fields should not affect network struct in the backend", func() {
 			nets, err := libpodNet.NetworkList()
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(nets).To(HaveLen(numberOfConfigFiles))
 
 			nets[0].Name = "myname"
 			nets, err = libpodNet.NetworkList()
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(nets).To(HaveLen(numberOfConfigFiles))
 			Expect(nets).ToNot(ContainElement(HaveNetworkName("myname")))
 
 			network, err := libpodNet.NetworkInspect("bridge")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			network.NetworkInterface = "abc"
 
 			network, err = libpodNet.NetworkInspect("bridge")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.NetworkInterface).ToNot(Equal("abc"))
 		})
 
 		It("bridge network", func() {
 			network, err := libpodNet.NetworkInspect("bridge")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("bridge"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.NetworkInterface).To(Equal("cni-podman9"))
@@ -1418,19 +1418,19 @@ var _ = Describe("Config", func() {
 
 		It("macvlan network", func() {
 			network, err := libpodNet.NetworkInspect("macvlan")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("macvlan"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.NetworkInterface).To(Equal("lo"))
 			Expect(network.Driver).To(Equal("macvlan"))
-			Expect(network.Subnets).To(HaveLen(0))
+			Expect(network.Subnets).To(BeEmpty())
 			// DHCP
 			Expect(network.IPAMOptions).To(HaveKeyWithValue("driver", "dhcp"))
 		})
 
 		It("internal network", func() {
 			network, err := libpodNet.NetworkInspect("internal")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("internal"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.NetworkInterface).To(Equal("cni-podman8"))
@@ -1443,7 +1443,7 @@ var _ = Describe("Config", func() {
 
 		It("bridge network with mtu", func() {
 			network, err := libpodNet.NetworkInspect("mtu")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("mtu"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.NetworkInterface).To(Equal("cni-podman13"))
@@ -1458,12 +1458,12 @@ var _ = Describe("Config", func() {
 
 		It("macvlan network with mtu", func() {
 			network, err := libpodNet.NetworkInspect("macvlan_mtu")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("macvlan_mtu"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.NetworkInterface).To(Equal("lo"))
 			Expect(network.Driver).To(Equal("macvlan"))
-			Expect(network.Subnets).To(HaveLen(0))
+			Expect(network.Subnets).To(BeEmpty())
 			Expect(network.Internal).To(BeFalse())
 			Expect(network.Options).To(HaveLen(1))
 			Expect(network.Options).To(HaveKeyWithValue("mtu", "1300"))
@@ -1473,7 +1473,7 @@ var _ = Describe("Config", func() {
 
 		It("bridge network with vlan", func() {
 			network, err := libpodNet.NetworkInspect("vlan")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("vlan"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.NetworkInterface).To(Equal("cni-podman14"))
@@ -1485,7 +1485,7 @@ var _ = Describe("Config", func() {
 
 		It("bridge network with labels", func() {
 			network, err := libpodNet.NetworkInspect("label")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("label"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.NetworkInterface).To(Equal("cni-podman15"))
@@ -1497,7 +1497,7 @@ var _ = Describe("Config", func() {
 
 		It("dual stack network", func() {
 			network, err := libpodNet.NetworkInspect("dualstack")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("dualstack"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.NetworkInterface).To(Equal("cni-podman21"))
@@ -1514,37 +1514,37 @@ var _ = Describe("Config", func() {
 
 		It("ipam static network", func() {
 			network, err := libpodNet.NetworkInspect("ipam-static")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("ipam-static"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.Driver).To(Equal("bridge"))
-			Expect(network.Subnets).To(HaveLen(0))
+			Expect(network.Subnets).To(BeEmpty())
 			Expect(network.IPAMOptions).To(HaveKeyWithValue("driver", "static"))
 		})
 
 		It("ipam none network", func() {
 			network, err := libpodNet.NetworkInspect("ipam-none")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("ipam-none"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.Driver).To(Equal("bridge"))
-			Expect(network.Subnets).To(HaveLen(0))
+			Expect(network.Subnets).To(BeEmpty())
 			Expect(network.IPAMOptions).To(HaveKeyWithValue("driver", "none"))
 		})
 
 		It("ipam empty network", func() {
 			network, err := libpodNet.NetworkInspect("ipam-empty")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("ipam-empty"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.Driver).To(Equal("bridge"))
-			Expect(network.Subnets).To(HaveLen(0))
+			Expect(network.Subnets).To(BeEmpty())
 			Expect(network.IPAMOptions).To(HaveKeyWithValue("driver", "none"))
 		})
 
 		It("bridge with isolate option", func() {
 			network, err := libpodNet.NetworkInspect("isolate")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("isolate"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.Driver).To(Equal("bridge"))
@@ -1556,10 +1556,10 @@ var _ = Describe("Config", func() {
 				"name": {"internal", "bridge"},
 			}
 			filterFuncs, err := util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err := libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(2))
 			Expect(networks).To(ConsistOf(HaveNetworkName("internal"), HaveNetworkName("bridge")))
 		})
@@ -1569,10 +1569,10 @@ var _ = Describe("Config", func() {
 				"name": {"inte", "bri"},
 			}
 			filterFuncs, err := util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err := libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(2))
 			Expect(networks).To(ConsistOf(HaveNetworkName("internal"), HaveNetworkName("bridge")))
 		})
@@ -1582,10 +1582,10 @@ var _ = Describe("Config", func() {
 				"id": {"3bed2cb3a3acf7b6a8ef408420cc682d5520e26976d354254f528c965612054f", "17f29b073143d8cd97b5bbe492bdeffec1c5fee55cc1fe2112c8b9335f8b6121"},
 			}
 			filterFuncs, err := util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err := libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(2))
 			Expect(networks).To(ConsistOf(HaveNetworkName("internal"), HaveNetworkName("bridge")))
 		})
@@ -1595,10 +1595,10 @@ var _ = Describe("Config", func() {
 				"id": {"3bed2cb3a3acf7b6a8ef408420cc682d5520e26976d354254f528c965612054f", "17f29b073143d8cd97b5bbe492bdeffec1c5fee55cc1fe2112c8b9335f8b6121"},
 			}
 			filterFuncs, err := util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err := libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(2))
 			Expect(networks).To(ConsistOf(HaveNetworkName("internal"), HaveNetworkName("bridge")))
 		})
@@ -1608,10 +1608,10 @@ var _ = Describe("Config", func() {
 				"id": {"3bed2cb3a3acf7b6a8ef408420", "17f29b073143d8cd97b5bbe492bde"},
 			}
 			filterFuncs, err := util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err := libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(2))
 			Expect(networks).To(ConsistOf(HaveNetworkName("internal"), HaveNetworkName("bridge")))
 		})
@@ -1621,10 +1621,10 @@ var _ = Describe("Config", func() {
 				"driver": {"bridge", "macvlan"},
 			}
 			filterFuncs, err := util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err := libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(numberOfConfigFiles))
 			Expect(networks).To(ConsistOf(HaveNetworkName("internal"), HaveNetworkName("bridge"),
 				HaveNetworkName("mtu"), HaveNetworkName("vlan"), HaveNetworkName("podman"),
@@ -1638,10 +1638,10 @@ var _ = Describe("Config", func() {
 				"label": {"mykey"},
 			}
 			filterFuncs, err := util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err := libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(1))
 			Expect(networks).To(ConsistOf(HaveNetworkName("label")))
 
@@ -1649,10 +1649,10 @@ var _ = Describe("Config", func() {
 				"label": {"mykey=value"},
 			}
 			filterFuncs, err = util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err = libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(1))
 			Expect(networks).To(ConsistOf(HaveNetworkName("label")))
 		})
@@ -1663,11 +1663,11 @@ var _ = Describe("Config", func() {
 				"label":  {"mykey"},
 			}
 			filterFuncs, err := util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(filterFuncs).To(HaveLen(2))
 
 			networks, err := libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(1))
 			Expect(networks).To(ConsistOf(HaveNetworkName("label")))
 
@@ -1676,11 +1676,11 @@ var _ = Describe("Config", func() {
 				"label":  {"mykey"},
 			}
 			filterFuncs, err = util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err = libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
-			Expect(networks).To(HaveLen(0))
+			Expect(err).ToNot(HaveOccurred())
+			Expect(networks).To(BeEmpty())
 		})
 
 		It("create bridge network with used interface name", func() {
@@ -1715,7 +1715,7 @@ var _ = Describe("Config", func() {
 
 		It("load invalid networks from disk", func() {
 			nets, err := libpodNet.NetworkList()
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(nets).To(HaveLen(2))
 			logString := logBuffer.String()
 			Expect(logString).To(ContainSubstring("noname.conflist: error parsing configuration list: no name"))
@@ -1738,12 +1738,12 @@ func grepNotFile(path, match string) {
 
 func grepFile(not bool, path, match string) {
 	data, err := os.ReadFile(path)
-	ExpectWithOffset(1, err).To(BeNil())
+	ExpectWithOffset(2, err).ToNot(HaveOccurred())
 	matcher := ContainSubstring(match)
 	if not {
 		matcher = Not(matcher)
 	}
-	ExpectWithOffset(1, string(data)).To(matcher)
+	ExpectWithOffset(2, string(data)).To(matcher)
 }
 
 // HaveNetworkName is a custom GomegaMatcher to match a network name
