@@ -1,5 +1,4 @@
 //go:build linux
-// +build linux
 
 package netavark_test
 
@@ -13,6 +12,7 @@ import (
 	"github.com/containers/common/libnetwork/netavark"
 	"github.com/containers/common/libnetwork/types"
 	"github.com/containers/common/libnetwork/util"
+	"github.com/containers/common/pkg/config"
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 	gomegaTypes "github.com/onsi/gomega/types"
@@ -51,7 +51,7 @@ var _ = Describe("Config", func() {
 	Context("basic network config tests", func() {
 		It("check default network config exists", func() {
 			networks, err := libpodNet.NetworkList()
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(1))
 			Expect(networks[0].Name).To(Equal("podman"))
 			Expect(networks[0].Driver).To(Equal("bridge"))
@@ -75,7 +75,7 @@ var _ = Describe("Config", func() {
 			now := time.Now().Add(-500 * time.Millisecond)
 			network := types.Network{}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			path := filepath.Join(networkConfDir, network1.Name+".json")
 			Expect(path).To(BeARegularFile())
@@ -96,29 +96,29 @@ var _ = Describe("Config", func() {
 
 			// inspect by name
 			network2, err := libpodNet.NetworkInspect(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			EqualNetwork(network2, network1)
 
 			// inspect by ID
 			network2, err = libpodNet.NetworkInspect(network1.ID)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			EqualNetwork(network2, network1)
 
 			// inspect by partial ID
 			network2, err = libpodNet.NetworkInspect(network1.ID[:10])
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			EqualNetwork(network2, network1)
 
 			// create a new interface to force a config load from disk
 			libpodNet, err = getNetworkInterface(networkConfDir)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			network2, err = libpodNet.NetworkInspect(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			EqualNetwork(network2, network1)
 
 			err = libpodNet.NetworkRemove(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(path).ToNot(BeARegularFile())
 
 			_, err = libpodNet.NetworkInspect(network1.Name)
@@ -129,13 +129,13 @@ var _ = Describe("Config", func() {
 		It("create two networks", func() {
 			network := types.Network{}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.Subnets).To(HaveLen(1))
 
 			network = types.Network{}
 			network2, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network2.Name).ToNot(Equal(network1.Name))
 			Expect(network2.ID).ToNot(Equal(network1.ID))
 			Expect(network2.NetworkInterface).ToNot(Equal(network1.NetworkInterface))
@@ -146,7 +146,7 @@ var _ = Describe("Config", func() {
 		It("fail when creating two networks with the same name", func() {
 			network := types.Network{}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.Subnets).To(HaveLen(1))
 
@@ -158,20 +158,20 @@ var _ = Describe("Config", func() {
 		It("return the same network when creating two networks with the same name and ignore", func() {
 			network := types.Network{}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.Subnets).To(HaveLen(1))
 
 			network = types.Network{Name: network1.Name}
 			network2, err := libpodNet.NetworkCreate(network, &types.NetworkCreateOptions{IgnoreIfExists: true})
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			EqualNetwork(network2, network1)
 		})
 
 		It("create bridge config", func() {
 			network := types.Network{Driver: "bridge"}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(filepath.Join(networkConfDir, network1.Name+".json")).To(BeARegularFile())
 			Expect(network1.ID).ToNot(BeEmpty())
@@ -197,7 +197,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(filepath.Join(networkConfDir, network1.Name+".json")).To(BeARegularFile())
 			Expect(network1.ID).ToNot(BeEmpty())
@@ -221,7 +221,7 @@ var _ = Describe("Config", func() {
 				NetworkInterface: "podman2",
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).To(Equal("podman2"))
@@ -243,7 +243,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -265,7 +265,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -278,10 +278,10 @@ var _ = Describe("Config", func() {
 
 			// reload configs from disk
 			libpodNet, err = getNetworkInterface(networkConfDir)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			// check the networks are identical
 			network2, err := libpodNet.NetworkInspect(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			EqualNetwork(network2, network1)
 		})
 
@@ -291,7 +291,7 @@ var _ = Describe("Config", func() {
 				IPv6Enabled: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -317,7 +317,7 @@ var _ = Describe("Config", func() {
 				IPv6Enabled: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -343,7 +343,7 @@ var _ = Describe("Config", func() {
 				IPv6Enabled: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -371,7 +371,7 @@ var _ = Describe("Config", func() {
 				IPv6Enabled: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -399,7 +399,7 @@ var _ = Describe("Config", func() {
 				IPv6Enabled: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -428,7 +428,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -468,7 +468,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -479,7 +479,7 @@ var _ = Describe("Config", func() {
 			Expect(network1.Subnets[0].LeaseRange.StartIP.String()).To(Equal(startIP))
 
 			err = libpodNet.NetworkRemove(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			endIP := "10.0.0.10"
 			network = types.Network{
@@ -491,7 +491,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err = libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(filepath.Join(networkConfDir, network1.Name+".json")).To(BeARegularFile())
 			Expect(network1.ID).ToNot(BeEmpty())
@@ -503,7 +503,7 @@ var _ = Describe("Config", func() {
 			Expect(network1.Subnets[0].LeaseRange.EndIP.String()).To(Equal(endIP))
 
 			err = libpodNet.NetworkRemove(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			network = types.Network{
 				Driver: "bridge",
@@ -515,7 +515,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err = libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.NetworkInterface).ToNot(BeEmpty())
@@ -575,7 +575,7 @@ var _ = Describe("Config", func() {
 				Name: name,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).To(Equal(name))
 			Expect(network1.NetworkInterface).ToNot(Equal(name))
 			Expect(network1.Driver).To(Equal("bridge"))
@@ -608,7 +608,7 @@ var _ = Describe("Config", func() {
 				Name: name,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).To(Equal(name))
 			Expect(network1.NetworkInterface).ToNot(Equal(name))
 			Expect(network1.Driver).To(Equal("bridge"))
@@ -629,7 +629,7 @@ var _ = Describe("Config", func() {
 				NetworkInterface: name,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(Equal(name))
 			Expect(network1.NetworkInterface).To(Equal(name))
 			Expect(network1.Driver).To(Equal("bridge"))
@@ -660,7 +660,7 @@ var _ = Describe("Config", func() {
 				DNSEnabled: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.DNSEnabled).To(BeTrue())
 			path := filepath.Join(networkConfDir, network1.Name+".json")
@@ -674,7 +674,7 @@ var _ = Describe("Config", func() {
 				Internal: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.Subnets).To(HaveLen(1))
 			Expect(network1.Subnets[0].Subnet.String()).ToNot(BeEmpty())
@@ -684,6 +684,7 @@ var _ = Describe("Config", func() {
 
 		It("update NetworkDNSServers AddDNSServers", func() {
 			libpodNet, err := netavark.NewNetworkInterface(&netavark.InitConfig{
+				Config:           &config.Config{},
 				NetworkConfigDir: networkConfDir,
 				NetworkRunDir:    networkConfDir,
 				NetavarkBinary:   "true",
@@ -697,12 +698,12 @@ var _ = Describe("Config", func() {
 				Name:              "test-network",
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.NetworkDNSServers).To(Equal([]string{"8.8.8.8", "3.3.3.3"}))
 			err = libpodNet.NetworkUpdate("test-network", types.NetworkUpdateOptions{AddDNSServers: []string{"8.8.8.8", "3.3.3.3", "7.7.7.7"}})
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			testNetwork, err := libpodNet.NetworkInspect("test-network")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(testNetwork.NetworkDNSServers).To(Equal([]string{"8.8.8.8", "3.3.3.3", "7.7.7.7"}))
 			err = libpodNet.NetworkUpdate("test-network", types.NetworkUpdateOptions{AddDNSServers: []string{"fake"}})
 			Expect(err).To(HaveOccurred())
@@ -710,6 +711,7 @@ var _ = Describe("Config", func() {
 
 		It("update NetworkDNSServers RemoveDNSServers", func() {
 			libpodNet, err := netavark.NewNetworkInterface(&netavark.InitConfig{
+				Config:           &config.Config{},
 				NetworkConfigDir: networkConfDir,
 				NetworkRunDir:    networkConfDir,
 				NetavarkBinary:   "true",
@@ -723,12 +725,12 @@ var _ = Describe("Config", func() {
 				Name:              "test-network",
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.NetworkDNSServers).To(Equal([]string{"8.8.8.8", "3.3.3.3"}))
 			err = libpodNet.NetworkUpdate("test-network", types.NetworkUpdateOptions{RemoveDNSServers: []string{"3.3.3.3"}})
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			testNetwork, err := libpodNet.NetworkInspect("test-network")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(testNetwork.NetworkDNSServers).To(Equal([]string{"8.8.8.8"}))
 			err = libpodNet.NetworkUpdate("test-network", types.NetworkUpdateOptions{RemoveDNSServers: []string{"fake"}})
 			Expect(err).To(HaveOccurred())
@@ -736,6 +738,7 @@ var _ = Describe("Config", func() {
 
 		It("update NetworkDNSServers Add and Remove DNSServers", func() {
 			libpodNet, err := netavark.NewNetworkInterface(&netavark.InitConfig{
+				Config:           &config.Config{},
 				NetworkConfigDir: networkConfDir,
 				NetworkRunDir:    networkConfDir,
 				NetavarkBinary:   "true",
@@ -749,12 +752,12 @@ var _ = Describe("Config", func() {
 				Name:              "test-network",
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.NetworkDNSServers).To(Equal([]string{"8.8.8.8", "3.3.3.3"}))
 			err = libpodNet.NetworkUpdate("test-network", types.NetworkUpdateOptions{RemoveDNSServers: []string{"3.3.3.3"}, AddDNSServers: []string{"7.7.7.7"}})
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			testNetwork, err := libpodNet.NetworkInspect("test-network")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(testNetwork.NetworkDNSServers).To(Equal([]string{"8.8.8.8", "7.7.7.7"}))
 		})
 
@@ -764,7 +767,7 @@ var _ = Describe("Config", func() {
 				DNSEnabled:        true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.NetworkDNSServers).To(Equal([]string{"8.8.8.8", "3.3.3.3"}))
 		})
 
@@ -795,7 +798,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.Labels).ToNot(BeNil())
 			Expect(network1.Labels).To(ContainElement("value"))
@@ -808,7 +811,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.Options).ToNot(BeNil())
 			path := filepath.Join(networkConfDir, network1.Name+".json")
@@ -844,7 +847,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.Options).ToNot(BeNil())
 			path := filepath.Join(networkConfDir, network1.Name+".json")
@@ -881,7 +884,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.Options).ToNot(BeNil())
 			path := filepath.Join(networkConfDir, network1.Name+".json")
@@ -910,6 +913,27 @@ var _ = Describe("Config", func() {
 			Expect(err.Error()).To(ContainSubstring(`vlan ID -1 must be between 0 and 4094`))
 		})
 
+		It("create two networks with vlan option and same bridge", func() {
+			networkOpts := types.Network{
+				NetworkInterface: "br0",
+				Options: map[string]string{
+					types.VLANOption: "5",
+				},
+			}
+			network1, err := libpodNet.NetworkCreate(networkOpts, nil)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(network1.Driver).To(Equal("bridge"))
+			Expect(network1.Options).To(HaveKeyWithValue("vlan", "5"))
+
+			// set a new vlan
+			networkOpts.Options[types.VLANOption] = "99"
+
+			network2, err := libpodNet.NetworkCreate(networkOpts, nil)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(network2.Driver).To(Equal("bridge"))
+			Expect(network2.Options).To(HaveKeyWithValue("vlan", "99"))
+		})
+
 		It("create network with vrf option", func() {
 			network := types.Network{
 				Options: map[string]string{
@@ -917,7 +941,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.Options).ToNot(BeNil())
 			path := filepath.Join(networkConfDir, network1.Name+".json")
@@ -953,14 +977,14 @@ var _ = Describe("Config", func() {
 			network1, err := libpodNet.NetworkCreate(network, nil)
 			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
-			Expect(network1.Internal).To(Equal(true))
-			Expect(network1.DNSEnabled).To(Equal(true))
+			Expect(network1.Internal).To(BeTrue())
+			Expect(network1.DNSEnabled).To(BeTrue())
 		})
 
 		It("network inspect partial ID", func() {
 			network := types.Network{Name: "net4"}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.ID).To(HaveLen(64))
 
 			network2, err := libpodNet.NetworkInspect(network1.ID[:10])
@@ -971,7 +995,7 @@ var _ = Describe("Config", func() {
 		It("network create two with same name", func() {
 			network := types.Network{Name: "net"}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).To(Equal("net"))
 			network = types.Network{Name: "net"}
 			_, err = libpodNet.NetworkCreate(network, nil)
@@ -985,7 +1009,7 @@ var _ = Describe("Config", func() {
 			Expect(err.Error()).To(Equal("default network podman cannot be removed"))
 
 			network, err := libpodNet.NetworkInspect("podman")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			err = libpodNet.NetworkRemove(network.ID)
 			Expect(err).To(HaveOccurred())
 			Expect(err.Error()).To(Equal("default network podman cannot be removed"))
@@ -998,7 +1022,7 @@ var _ = Describe("Config", func() {
 			n2, _ := types.ParseCIDR(subnet2)
 			network := types.Network{Subnets: []types.Subnet{{Subnet: n}, {Subnet: n2}}}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Subnets).To(HaveLen(2))
 			network = types.Network{Subnets: []types.Subnet{{Subnet: n}}}
 			_, err = libpodNet.NetworkCreate(network, nil)
@@ -1050,7 +1074,7 @@ var _ = Describe("Config", func() {
 			}
 			net1, err := libpodNet.NetworkCreate(network, nil)
 			Expect(err).ToNot(HaveOccurred())
-			Expect(net1.Internal).To(Equal(true))
+			Expect(net1.Internal).To(BeTrue())
 		})
 
 		It("create macvlan config with subnet", func() {
@@ -1063,7 +1087,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			path := filepath.Join(networkConfDir, network1.Name+".json")
 			Expect(path).To(BeARegularFile())
@@ -1092,7 +1116,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.ID).ToNot(BeEmpty())
 			Expect(network1.Driver).To(Equal("macvlan"))
@@ -1113,7 +1137,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			path := filepath.Join(networkConfDir, network1.Name+".json")
 			Expect(path).To(BeARegularFile())
@@ -1206,7 +1230,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.Options).To(HaveKeyWithValue("mode", "private"))
 		})
@@ -1258,7 +1282,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.Options).To(HaveKeyWithValue("mtu", "9000"))
 		})
@@ -1271,18 +1295,18 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.IPAMOptions).ToNot(BeEmpty())
 			Expect(network1.IPAMOptions).To(HaveKeyWithValue("driver", "none"))
-			Expect(network1.Subnets).To(HaveLen(0))
+			Expect(network1.Subnets).To(BeEmpty())
 
 			// reload configs from disk
 			libpodNet, err = getNetworkInterface(networkConfDir)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			network2, err := libpodNet.NetworkInspect(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			EqualNetwork(network2, network1)
 		})
 
@@ -1312,19 +1336,19 @@ var _ = Describe("Config", func() {
 				DNSEnabled: true,
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("macvlan"))
 			Expect(network1.DNSEnabled).To(BeFalse())
 			Expect(network1.IPAMOptions).ToNot(BeEmpty())
 			Expect(network1.IPAMOptions).To(HaveKeyWithValue("driver", "none"))
-			Expect(network1.Subnets).To(HaveLen(0))
+			Expect(network1.Subnets).To(BeEmpty())
 
 			// reload configs from disk
 			libpodNet, err = getNetworkInterface(networkConfDir)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			network2, err := libpodNet.NetworkInspect(network1.Name)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			EqualNetwork(network2, network1)
 		})
 
@@ -1355,7 +1379,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			path := filepath.Join(networkConfDir, network1.Name+".json")
 			Expect(path).To(BeARegularFile())
@@ -1396,7 +1420,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Name).ToNot(BeEmpty())
 			Expect(network1.Options).To(HaveKeyWithValue("mode", "l2"))
 		})
@@ -1426,7 +1450,7 @@ var _ = Describe("Config", func() {
 					},
 				}
 				network1, err := libpodNet.NetworkCreate(network, nil)
-				Expect(err).To(BeNil())
+				Expect(err).ToNot(HaveOccurred())
 				Expect(network1.Driver).To(Equal("bridge"))
 				Expect(network1.Options).ToNot(BeNil())
 				path := filepath.Join(networkConfDir, network1.Name+".json")
@@ -1443,7 +1467,7 @@ var _ = Describe("Config", func() {
 				},
 			}
 			network1, err := libpodNet.NetworkCreate(network, nil)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network1.Driver).To(Equal("bridge"))
 			Expect(network1.Options).ToNot(BeNil())
 			path := filepath.Join(networkConfDir, network1.Name+".json")
@@ -1475,7 +1499,7 @@ var _ = Describe("Config", func() {
 			},
 		}
 		network1, err := libpodNet.NetworkCreate(network, nil)
-		Expect(err).To(BeNil())
+		Expect(err).ToNot(HaveOccurred())
 		Expect(network1.Name).ToNot(BeEmpty())
 		Expect(network1.Routes).To(HaveLen(1))
 		Expect(network1.Routes[0].Destination.String()).To(Equal(dest))
@@ -1494,7 +1518,7 @@ var _ = Describe("Config", func() {
 			},
 		}
 		network1, err := libpodNet.NetworkCreate(network, nil)
-		Expect(err).To(BeNil())
+		Expect(err).ToNot(HaveOccurred())
 		Expect(network1.Name).ToNot(BeEmpty())
 		Expect(network1.Routes).To(HaveLen(1))
 		Expect(network1.Routes[0].Destination.String()).To(Equal(dest))
@@ -1519,7 +1543,7 @@ var _ = Describe("Config", func() {
 		}
 
 		network1, err := libpodNet.NetworkCreate(network, nil)
-		Expect(err).To(BeNil())
+		Expect(err).ToNot(HaveOccurred())
 		Expect(network1.Name).ToNot(BeEmpty())
 		Expect(network1.Routes).To(HaveLen(1))
 		Expect(network1.Routes[0].Destination.String()).To(Equal(dest))
@@ -1538,7 +1562,7 @@ var _ = Describe("Config", func() {
 			},
 		}
 		network1, err := libpodNet.NetworkCreate(network, nil)
-		Expect(err).To(BeNil())
+		Expect(err).ToNot(HaveOccurred())
 		Expect(network1.Name).ToNot(BeEmpty())
 		Expect(network1.Routes).To(HaveLen(1))
 		Expect(network1.Routes[0].Destination.String()).To(Equal(dest))
@@ -1557,7 +1581,7 @@ var _ = Describe("Config", func() {
 			},
 		}
 		network1, err := libpodNet.NetworkCreate(network, nil)
-		Expect(err).To(BeNil())
+		Expect(err).ToNot(HaveOccurred())
 		Expect(network1.Name).ToNot(BeEmpty())
 		Expect(network1.Routes).To(HaveLen(1))
 		Expect(network1.Routes[0].Destination.String()).To(Equal(dest))
@@ -1581,7 +1605,7 @@ var _ = Describe("Config", func() {
 			},
 		}
 		network1, err := libpodNet.NetworkCreate(network, nil)
-		Expect(err).To(BeNil())
+		Expect(err).ToNot(HaveOccurred())
 		Expect(network1.Name).ToNot(BeEmpty())
 		Expect(network1.Routes).To(HaveLen(1))
 		Expect(network1.Routes[0].Destination.String()).To(Equal(dest))
@@ -1747,6 +1771,19 @@ var _ = Describe("Config", func() {
 		Expect(err.Error()).To(Equal("route gateway nil"))
 	})
 
+	It("create macvlan config with metric option", func() {
+		network := types.Network{
+			Driver: "macvlan",
+			Options: map[string]string{
+				"metric": "99",
+			},
+		}
+		network1, err := libpodNet.NetworkCreate(network, nil)
+		Expect(err).ToNot(HaveOccurred())
+		Expect(network1.Options).To(HaveLen(1))
+		Expect(network1.Options["metric"]).To(Equal("99"))
+	})
+
 	It("create bridge config with no_default_route", func() {
 		network := types.Network{
 			Driver: "bridge",
@@ -1755,7 +1792,7 @@ var _ = Describe("Config", func() {
 			},
 		}
 		network1, err := libpodNet.NetworkCreate(network, nil)
-		Expect(err).To(BeNil())
+		Expect(err).ToNot(HaveOccurred())
 		Expect(network1.Options).To(HaveLen(1))
 		Expect(network1.Options["no_default_route"]).To(Equal("true"))
 	})
@@ -1768,7 +1805,7 @@ var _ = Describe("Config", func() {
 			},
 		}
 		network1, err := libpodNet.NetworkCreate(network, nil)
-		Expect(err).To(BeNil())
+		Expect(err).ToNot(HaveOccurred())
 		Expect(network1.Options).To(HaveLen(1))
 		Expect(network1.Options["no_default_route"]).To(Equal("true"))
 	})
@@ -1786,7 +1823,7 @@ var _ = Describe("Config", func() {
 			},
 		}
 		network1, err := libpodNet.NetworkCreate(network, nil)
-		Expect(err).To(BeNil())
+		Expect(err).ToNot(HaveOccurred())
 		Expect(network1.Options).To(HaveLen(1))
 		Expect(network1.Options["no_default_route"]).To(Equal("true"))
 	})
@@ -1854,7 +1891,7 @@ var _ = Describe("Config", func() {
 
 		It("load networks from disk", func() {
 			nets, err := libpodNet.NetworkList()
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(nets).To(HaveLen(9))
 			// test the we do not show logrus warnings/errors
 			logString := logBuffer.String()
@@ -1863,27 +1900,27 @@ var _ = Describe("Config", func() {
 
 		It("change network struct fields should not affect network struct in the backend", func() {
 			nets, err := libpodNet.NetworkList()
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(nets).To(HaveLen(9))
 
 			nets[0].Name = "myname"
 			nets, err = libpodNet.NetworkList()
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(nets).To(HaveLen(9))
 			Expect(nets).ToNot(ContainElement(HaveNetworkName("myname")))
 
 			network, err := libpodNet.NetworkInspect("bridge")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			network.NetworkInterface = "abc"
 
 			network, err = libpodNet.NetworkInspect("bridge")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.NetworkInterface).ToNot(Equal("abc"))
 		})
 
 		It("bridge network", func() {
 			network, err := libpodNet.NetworkInspect("bridge")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("bridge"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.NetworkInterface).To(Equal("podman9"))
@@ -1899,7 +1936,7 @@ var _ = Describe("Config", func() {
 
 		It("internal network", func() {
 			network, err := libpodNet.NetworkInspect("internal")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("internal"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.NetworkInterface).To(Equal("podman8"))
@@ -1912,7 +1949,7 @@ var _ = Describe("Config", func() {
 
 		It("bridge network with mtu", func() {
 			network, err := libpodNet.NetworkInspect("mtu")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("mtu"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.NetworkInterface).To(Equal("podman13"))
@@ -1927,7 +1964,7 @@ var _ = Describe("Config", func() {
 
 		It("bridge network with vlan", func() {
 			network, err := libpodNet.NetworkInspect("vlan")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("vlan"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.NetworkInterface).To(Equal("podman14"))
@@ -1939,7 +1976,7 @@ var _ = Describe("Config", func() {
 
 		It("bridge network with labels", func() {
 			network, err := libpodNet.NetworkInspect("label")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("label"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.NetworkInterface).To(Equal("podman15"))
@@ -1951,7 +1988,7 @@ var _ = Describe("Config", func() {
 
 		It("bridge network with route metric", func() {
 			network, err := libpodNet.NetworkInspect("metric")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("metric"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.NetworkInterface).To(Equal("podman100"))
@@ -1963,7 +2000,7 @@ var _ = Describe("Config", func() {
 
 		It("dual stack network", func() {
 			network, err := libpodNet.NetworkInspect("dualstack")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("dualstack"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.NetworkInterface).To(Equal("podman21"))
@@ -1980,7 +2017,7 @@ var _ = Describe("Config", func() {
 
 		It("bridge network with vrf", func() {
 			network, err := libpodNet.NetworkInspect("vrf")
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(network.Name).To(Equal("vrf"))
 			Expect(network.ID).To(HaveLen(64))
 			Expect(network.NetworkInterface).To(Equal("podman16"))
@@ -1995,10 +2032,10 @@ var _ = Describe("Config", func() {
 				"name": {"internal", "bridge"},
 			}
 			filterFuncs, err := util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err := libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(2))
 			Expect(networks).To(ConsistOf(HaveNetworkName("internal"), HaveNetworkName("bridge")))
 		})
@@ -2008,10 +2045,10 @@ var _ = Describe("Config", func() {
 				"name": {"inte", "bri"},
 			}
 			filterFuncs, err := util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err := libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(2))
 			Expect(networks).To(ConsistOf(HaveNetworkName("internal"), HaveNetworkName("bridge")))
 		})
@@ -2021,10 +2058,10 @@ var _ = Describe("Config", func() {
 				"id": {"3bed2cb3a3acf7b6a8ef408420cc682d5520e26976d354254f528c965612054f", "17f29b073143d8cd97b5bbe492bdeffec1c5fee55cc1fe2112c8b9335f8b6121"},
 			}
 			filterFuncs, err := util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err := libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(2))
 			Expect(networks).To(ConsistOf(HaveNetworkName("internal"), HaveNetworkName("bridge")))
 		})
@@ -2034,10 +2071,10 @@ var _ = Describe("Config", func() {
 				"id": {"3bed2cb3a3acf7b6a8ef40.*", "17f29b073143d8cd97b5bbe492bdeffec1c5fee55cc1fe2112c8b9335f8b6121"},
 			}
 			filterFuncs, err := util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err := libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(2))
 			Expect(networks).To(ConsistOf(HaveNetworkName("internal"), HaveNetworkName("bridge")))
 		})
@@ -2047,10 +2084,10 @@ var _ = Describe("Config", func() {
 				"id": {"3bed2cb3a3acf7b6a8ef408420", "17f29b073143d8cd97b5bbe492bde"},
 			}
 			filterFuncs, err := util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err := libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(2))
 			Expect(networks).To(ConsistOf(HaveNetworkName("internal"), HaveNetworkName("bridge")))
 		})
@@ -2060,10 +2097,10 @@ var _ = Describe("Config", func() {
 				"driver": {"bridge"},
 			}
 			filterFuncs, err := util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err := libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(9))
 			Expect(networks).To(ConsistOf(HaveNetworkName("internal"), HaveNetworkName("bridge"),
 				HaveNetworkName("mtu"), HaveNetworkName("vlan"), HaveNetworkName("podman"),
@@ -2076,10 +2113,10 @@ var _ = Describe("Config", func() {
 				"label": {"mykey"},
 			}
 			filterFuncs, err := util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err := libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(1))
 			Expect(networks).To(ConsistOf(HaveNetworkName("label")))
 
@@ -2087,10 +2124,10 @@ var _ = Describe("Config", func() {
 				"label": {"mykey=value"},
 			}
 			filterFuncs, err = util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err = libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(1))
 			Expect(networks).To(ConsistOf(HaveNetworkName("label")))
 		})
@@ -2101,11 +2138,11 @@ var _ = Describe("Config", func() {
 				"label":  {"mykey"},
 			}
 			filterFuncs, err := util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(filterFuncs).To(HaveLen(2))
 
 			networks, err := libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(networks).To(HaveLen(1))
 			Expect(networks).To(ConsistOf(HaveNetworkName("label")))
 
@@ -2114,11 +2151,11 @@ var _ = Describe("Config", func() {
 				"label":  {"mykey"},
 			}
 			filterFuncs, err = util.GenerateNetworkFilters(filters)
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 
 			networks, err = libpodNet.NetworkList(filterFuncs...)
-			Expect(err).To(BeNil())
-			Expect(networks).To(HaveLen(0))
+			Expect(err).ToNot(HaveOccurred())
+			Expect(networks).To(BeEmpty())
 		})
 
 		It("create bridge network with used interface name", func() {
@@ -2153,12 +2190,12 @@ var _ = Describe("Config", func() {
 
 		It("load invalid networks from disk", func() {
 			nets, err := libpodNet.NetworkList()
-			Expect(err).To(BeNil())
+			Expect(err).ToNot(HaveOccurred())
 			Expect(nets).To(HaveLen(1))
 			logString := logBuffer.String()
 			Expect(logString).To(ContainSubstring("Error reading network config file \\\"%s/broken.json\\\": unexpected EOF", networkConfDir))
 			Expect(logString).To(ContainSubstring("Network config \\\"%s/invalid name.json\\\" has invalid name: \\\"invalid name\\\", skipping: names must match [a-zA-Z0-9][a-zA-Z0-9_.-]*: invalid argument", networkConfDir))
-			Expect(logString).To(ContainSubstring("Network config name \\\"name_miss\\\" does not match file name \\\"name_missmatch.json\\\", skipping"))
+			Expect(logString).To(ContainSubstring("Network config name \\\"name_miss\\\" does not match file name \\\"name_mismatch.json\\\", skipping"))
 			Expect(logString).To(ContainSubstring("Network config \\\"%s/wrongID.json\\\" could not be parsed, skipping: invalid network ID \\\"someID\\\"", networkConfDir))
 			Expect(logString).To(ContainSubstring("Network config \\\"%s/invalid_gateway.json\\\" could not be parsed, skipping: gateway 10.89.100.1 not in subnet 10.89.9.0/24", networkConfDir))
 		})
@@ -2167,7 +2204,7 @@ var _ = Describe("Config", func() {
 
 func grepInFile(path, match string) {
 	data, err := os.ReadFile(path)
-	ExpectWithOffset(1, err).To(BeNil())
+	ExpectWithOffset(1, err).ToNot(HaveOccurred())
 	ExpectWithOffset(1, string(data)).To(ContainSubstring(match))
 }
 
