@@ -1,5 +1,4 @@
 //go:build linux
-// +build linux
 
 package slirp4netns
 
@@ -87,16 +86,6 @@ type SetupOptions struct {
 	Pdeathsig syscall.Signal
 }
 
-// SetupResult return type from Setup()
-type SetupResult struct {
-	// Pid of the created slirp4netns process
-	Pid int
-	// Subnet which is used by slirp4netns
-	Subnet *net.IPNet
-	// IPv6 whenever Ipv6 is enabled in slirp4netns
-	IPv6 bool
-}
-
 type logrusDebugWriter struct {
 	prefix string
 }
@@ -211,7 +200,7 @@ func createBasicSlirpCmdArgs(options *networkOptions, features *slirpFeatures) (
 		cmdArgs = append(cmdArgs, "--disable-host-loopback")
 	}
 	if options.mtu > -1 && features.HasMTU {
-		cmdArgs = append(cmdArgs, fmt.Sprintf("--mtu=%d", options.mtu))
+		cmdArgs = append(cmdArgs, "--mtu="+strconv.Itoa(options.mtu))
 	}
 	if !options.noPivotRoot && features.HasEnableSandbox {
 		cmdArgs = append(cmdArgs, "--enable-sandbox")
@@ -222,33 +211,33 @@ func createBasicSlirpCmdArgs(options *networkOptions, features *slirpFeatures) (
 
 	if options.cidr != "" {
 		if !features.HasCIDR {
-			return nil, fmt.Errorf("cidr not supported")
+			return nil, errors.New("cidr not supported")
 		}
-		cmdArgs = append(cmdArgs, fmt.Sprintf("--cidr=%s", options.cidr))
+		cmdArgs = append(cmdArgs, "--cidr="+options.cidr)
 	}
 
 	if options.enableIPv6 {
 		if !features.HasIPv6 {
-			return nil, fmt.Errorf("enable_ipv6 not supported")
+			return nil, errors.New("enable_ipv6 not supported")
 		}
 		cmdArgs = append(cmdArgs, "--enable-ipv6")
 	}
 
 	if options.outboundAddr != "" {
 		if !features.HasOutboundAddr {
-			return nil, fmt.Errorf("outbound_addr not supported")
+			return nil, errors.New("outbound_addr not supported")
 		}
-		cmdArgs = append(cmdArgs, fmt.Sprintf("--outbound-addr=%s", options.outboundAddr))
+		cmdArgs = append(cmdArgs, "--outbound-addr="+options.outboundAddr)
 	}
 
 	if options.outboundAddr6 != "" {
 		if !features.HasOutboundAddr || !features.HasIPv6 {
-			return nil, fmt.Errorf("outbound_addr6 not supported")
+			return nil, errors.New("outbound_addr6 not supported")
 		}
 		if !options.enableIPv6 {
-			return nil, fmt.Errorf("enable_ipv6=true is required for outbound_addr6")
+			return nil, errors.New("enable_ipv6=true is required for outbound_addr6")
 		}
-		cmdArgs = append(cmdArgs, fmt.Sprintf("--outbound-addr6=%s", options.outboundAddr6))
+		cmdArgs = append(cmdArgs, "--outbound-addr6="+options.outboundAddr6)
 	}
 
 	return cmdArgs, nil
@@ -301,7 +290,7 @@ func Setup(opts *SetupOptions) (*SetupResult, error) {
 
 	var apiSocket string
 	if havePortMapping && netOptions.isSlirpHostForward {
-		apiSocket = filepath.Join(opts.Config.Engine.TmpDir, fmt.Sprintf("%s.net", opts.ContainerID))
+		apiSocket = filepath.Join(opts.Config.Engine.TmpDir, opts.ContainerID+".net")
 		cmdArgs = append(cmdArgs, "--api-socket", apiSocket)
 	}
 
@@ -611,7 +600,7 @@ func SetupRootlessPortMappingViaRLK(opts *SetupOptions, slirpSubnet *net.IPNet,
 		if stdoutStr != "" {
 			// err contains full debug log and too verbose, so return stdoutStr
 			logrus.Debug(err)
-			return fmt.Errorf("rootlessport " + strings.TrimSuffix(stdoutStr, "\n"))
+			return errors.New("rootlessport " + strings.TrimSuffix(stdoutStr, "\n"))
 		}
 		return err
 	}
@@ -656,7 +645,7 @@ func setupRootlessPortMappingViaSlirp(ports []types.PortMapping, cmd *exec.Cmd,
 			if hostIP == "" {
 				hostIP = "0.0.0.0"
 			}
-			for i := uint16(0); i < port.Range; i++ {
+			for i := range port.Range {
 				if err := openSlirp4netnsPort(apiSocket, protocol, hostIP, port.HostPort+i, port.ContainerPort+i); err != nil {
 					return err
 				}
@@ -706,7 +695,7 @@ func openSlirp4netnsPort(apiSocket, proto, hostip string, hostport, guestport ui
 	}
 	// if there is no 'error' key in the received JSON data, then the operation was
 	// successful.
-	var y map[string]interface{}
+	var y map[string]any
 	if err := json.Unmarshal(buf[0:readLength], &y); err != nil {
 		return fmt.Errorf("parsing error status from slirp4netns: %w", err)
 	}
