@@ -1,5 +1,4 @@
 //go:build !remote
-// +build !remote
 
 package config
 
@@ -18,13 +17,13 @@ import (
 var _ = Describe("Config Local", func() {
 	It("should not fail on invalid NetworkConfigDir", func() {
 		defConf, err := defaultConfig()
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 		// Given
 		tmpfile := path.Join(os.TempDir(), "wrong-file")
 		file, err := os.Create(tmpfile)
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		file.Close()
 		defer os.Remove(tmpfile)
 		defConf.Network.NetworkConfigDir = tmpfile
@@ -34,12 +33,12 @@ var _ = Describe("Config Local", func() {
 		err = defConf.Network.Validate()
 
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 	})
 
 	It("should not fail on invalid CNIPluginDirs", func() {
 		defConf, err := defaultConfig()
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 		validDirPath, err := os.MkdirTemp("", "config-empty")
@@ -56,12 +55,12 @@ var _ = Describe("Config Local", func() {
 		err = defConf.Network.Validate()
 
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 	})
 
 	It("should fail on invalid subnet pool", func() {
 		defConf, err := defaultConfig()
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 		validDirPath, err := os.MkdirTemp("", "config-empty")
@@ -82,7 +81,7 @@ var _ = Describe("Config Local", func() {
 		err = defConf.Network.Validate()
 
 		// Then
-		gomega.Expect(err).NotTo(gomega.BeNil())
+		gomega.Expect(err).To(gomega.HaveOccurred())
 
 		defConf.Network.DefaultSubnetPools = []SubnetPool{
 			{Base: &net, Size: 33},
@@ -92,13 +91,13 @@ var _ = Describe("Config Local", func() {
 		err = defConf.Network.Validate()
 
 		// Then
-		gomega.Expect(err).NotTo(gomega.BeNil())
+		gomega.Expect(err).To(gomega.HaveOccurred())
 	})
 
 	It("parse network subnet pool", func() {
 		config, err := NewConfig("testdata/containers_default.conf")
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		net1, _ := types.ParseCIDR("10.89.0.0/16")
 		net2, _ := types.ParseCIDR("10.90.0.0/15")
 		gomega.Expect(config.Network.DefaultSubnetPools).To(gomega.Equal(
@@ -115,42 +114,54 @@ var _ = Describe("Config Local", func() {
 	It("parse dns port", func() {
 		// Given
 		config, err := New(nil)
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config.Network.DNSBindPort).To(gomega.Equal(uint16(0)))
 		// When
 		config2, err := NewConfig("testdata/containers_default.conf")
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config2.Network.DNSBindPort).To(gomega.Equal(uint16(1153)))
 	})
 
+	It("test firewall", func() {
+		// Given
+		config, err := New(nil)
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config.Network.FirewallDriver).To(gomega.Equal(string("")))
+		// When
+		config2, err := NewConfig("testdata/containers_default.conf")
+		// Then
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config2.Network.FirewallDriver).To(gomega.Equal("none"))
+	})
+
 	It("parse pasta_options", func() {
 		// Given
 		config, err := New(nil)
-		gomega.Expect(err).To(gomega.BeNil())
-		gomega.Expect(config.Network.PastaOptions.Get()).To(gomega.HaveLen(0))
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config.Network.PastaOptions.Get()).To(gomega.BeEmpty())
 		// When
 		config2, err := NewConfig("testdata/containers_default.conf")
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config2.Network.PastaOptions.Get()).To(gomega.Equal([]string{"-t", "auto"}))
 	})
 
 	It("parse default_rootless_network_cmd", func() {
 		// Given
 		config, err := NewConfig("")
-		gomega.Expect(err).To(gomega.BeNil())
-		gomega.Expect(config.Network.DefaultRootlessNetworkCmd).To(gomega.Equal("slirp4netns"))
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config.Network.DefaultRootlessNetworkCmd).To(gomega.Equal("pasta"))
 		// When
 		config2, err := NewConfig("testdata/containers_default.conf")
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
-		gomega.Expect(config2.Network.DefaultRootlessNetworkCmd).To(gomega.Equal("pasta"))
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config2.Network.DefaultRootlessNetworkCmd).To(gomega.Equal("slirp4netns"))
 	})
 
 	It("should fail on invalid device mode", func() {
 		defConf, err := defaultConfig()
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 		// Given
@@ -160,12 +171,12 @@ var _ = Describe("Config Local", func() {
 		err = defConf.Containers.Validate()
 
 		// Then
-		gomega.Expect(err).NotTo(gomega.BeNil())
+		gomega.Expect(err).To(gomega.HaveOccurred())
 	})
 
 	It("should fail on invalid first device", func() {
 		defConf, err := defaultConfig()
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 		// Given
@@ -175,12 +186,12 @@ var _ = Describe("Config Local", func() {
 		err = defConf.Containers.Validate()
 
 		// Then
-		gomega.Expect(err).NotTo(gomega.BeNil())
+		gomega.Expect(err).To(gomega.HaveOccurred())
 	})
 
 	It("should fail on invalid second device", func() {
 		defConf, err := defaultConfig()
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 		// Given
@@ -190,12 +201,12 @@ var _ = Describe("Config Local", func() {
 		err = defConf.Containers.Validate()
 
 		// Then
-		gomega.Expect(err).NotTo(gomega.BeNil())
+		gomega.Expect(err).To(gomega.HaveOccurred())
 	})
 
 	It("should fail on invalid device", func() {
 		defConf, err := defaultConfig()
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 		// Given
@@ -205,12 +216,12 @@ var _ = Describe("Config Local", func() {
 		err = defConf.Containers.Validate()
 
 		// Then
-		gomega.Expect(err).NotTo(gomega.BeNil())
+		gomega.Expect(err).To(gomega.HaveOccurred())
 	})
 
 	It("should fail on wrong invalid device specification", func() {
 		defConf, err := defaultConfig()
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 		// Given
@@ -220,12 +231,57 @@ var _ = Describe("Config Local", func() {
 		err = defConf.Containers.Validate()
 
 		// Then
-		gomega.Expect(err).NotTo(gomega.BeNil())
+		gomega.Expect(err).To(gomega.HaveOccurred())
+	})
+
+	It("should fail on invalid interface_name", func() {
+		defConf, err := defaultConfig()
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(defConf).NotTo(gomega.BeNil())
+
+		// Given
+		defConf.Containers.InterfaceName = "random"
+
+		// When
+		err = defConf.Containers.Validate()
+
+		// Then
+		gomega.Expect(err).To(gomega.HaveOccurred())
+	})
+
+	It("should succeed on good interface_name", func() {
+		defConf, err := defaultConfig()
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(defConf).NotTo(gomega.BeNil())
+
+		// Given
+		defConf.Containers.InterfaceName = "device"
+
+		// When
+		err = defConf.Containers.Validate()
+
+		// Then
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+	})
+
+	It("should succeed on default interface_name", func() {
+		defConf, err := defaultConfig()
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(defConf).NotTo(gomega.BeNil())
+
+		// Given
+		defConf.Containers.InterfaceName = ""
+
+		// When
+		err = defConf.Containers.Validate()
+
+		// Then
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 	})
 
 	It("should fail on bad timezone", func() {
 		defConf, err := defaultConfig()
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 		// Given
@@ -235,12 +291,12 @@ var _ = Describe("Config Local", func() {
 		err = defConf.Containers.Validate()
 
 		// Then
-		gomega.Expect(err).NotTo(gomega.BeNil())
+		gomega.Expect(err).To(gomega.HaveOccurred())
 	})
 
 	It("should succeed on good timezone", func() {
 		defConf, err := defaultConfig()
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 		// Given
@@ -250,12 +306,12 @@ var _ = Describe("Config Local", func() {
 		err = defConf.Containers.Validate()
 
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 	})
 
 	It("should succeed on local timezone", func() {
 		defConf, err := defaultConfig()
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 		// Given
@@ -265,12 +321,12 @@ var _ = Describe("Config Local", func() {
 		err = defConf.Containers.Validate()
 
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 	})
 
 	It("should fail on wrong DefaultUlimits", func() {
 		defConf, err := defaultConfig()
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 		// Given
@@ -280,7 +336,7 @@ var _ = Describe("Config Local", func() {
 		err = defConf.Containers.Validate()
 
 		// Then
-		gomega.Expect(err).NotTo(gomega.BeNil())
+		gomega.Expect(err).To(gomega.HaveOccurred())
 	})
 
 	It("should return containers engine env", func() {
@@ -289,18 +345,44 @@ var _ = Describe("Config Local", func() {
 		// When
 		config, err := NewConfig("testdata/containers_default.conf")
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config.Engine.Env.Get()).To(gomega.BeEquivalentTo(expectedEnv))
 		gomega.Expect(os.Getenv("super")).To(gomega.BeEquivalentTo("duper"))
 		gomega.Expect(os.Getenv("foo")).To(gomega.BeEquivalentTo("bar"))
 	})
 
+	It("should override cdi_spec_dirs if provided", func() {
+		// Given
+		config1, err := New(nil)
+		// Then
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config1.Engine.CdiSpecDirs.Get()).To(gomega.Equal([]string{"/etc/cdi"}))
+
+		// Given default just get default
+		config2, err := NewConfig("testdata/containers_default.conf")
+		// Then
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config2.Engine.CdiSpecDirs.Get()).To(gomega.Equal([]string{"/etc/cdi"}))
+
+		// Given override just get override
+		config3, err := NewConfig("testdata/containers_override.conf")
+		// Then
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config3.Engine.CdiSpecDirs.Get()).To(gomega.Equal([]string{"/somepath"}))
+
+		// Given override just get override
+		config4, err := NewConfig("testdata/containers_override2.conf")
+		// Then
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config4.Engine.CdiSpecDirs.Get()).To(gomega.Equal([]string{"/somepath", "/some_other_path"}))
+	})
+
 	It("Expect Remote to be False", func() {
 		// Given
 		// When
 		config, err := New(nil)
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config.Engine.Remote).To(gomega.BeFalse())
 	})
 
@@ -309,20 +391,20 @@ var _ = Describe("Config Local", func() {
 			"PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin",
 		}
 		// Given we do
-		oldContainersConf, envSet := os.LookupEnv("CONTAINERS_CONF")
-		os.Setenv("CONTAINERS_CONF", "/dev/null")
+		oldContainersConf, envSet := os.LookupEnv(containersConfEnv)
+		os.Setenv(containersConfEnv, "/dev/null")
 
 		// When
 		config, err := Default()
 
 		// Undo that
 		if envSet {
-			os.Setenv("CONTAINERS_CONF", oldContainersConf)
+			os.Setenv(containersConfEnv, oldContainersConf)
 		} else {
-			os.Unsetenv("CONTAINERS_CONF")
+			os.Unsetenv(containersConfEnv)
 		}
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config.GetDefaultEnv()).To(gomega.BeEquivalentTo(envs))
 		config.Containers.HTTPProxy = true
 		gomega.Expect(config.GetDefaultEnv()).To(gomega.BeEquivalentTo(envs))
@@ -338,52 +420,12 @@ var _ = Describe("Config Local", func() {
 		gomega.Expect(envString).To(gomega.ContainSubstring("HTTP_PROXY=localhost"))
 	})
 
-	It("write", func() {
-		tmpfile := "containers.conf.test"
-		oldContainersConf, envSet := os.LookupEnv("CONTAINERS_CONF")
-		os.Setenv("CONTAINERS_CONF", tmpfile)
-		defer func() {
-			if envSet {
-				os.Setenv("CONTAINERS_CONF", oldContainersConf)
-			} else {
-				os.Unsetenv("CONTAINERS_CONF")
-			}
-		}()
-
-		config, err := ReadCustomConfig()
-		gomega.Expect(err).To(gomega.BeNil())
-		config.Containers.Devices.Set([]string{
-			"/dev/null:/dev/null:rw",
-			"/dev/sdc/",
-			"/dev/sdc:/dev/xvdc",
-			"/dev/sdc:rm",
-		})
-		boolTrue := true
-		config.Containers.Env.Set([]string{"A", "B", "C"})
-		config.Containers.Env.Attributes.Append = &boolTrue
-
-		err = config.Write()
-		gomega.Expect(err).To(gomega.BeNil())
-
-		fi, err := os.Stat(tmpfile)
-		gomega.Expect(err).To(gomega.BeNil())
-		perm := int(fi.Mode().Perm())
-		// 436 decimal = 644 octal
-		gomega.Expect(perm).To(gomega.Equal(420))
-		defer os.Remove(tmpfile)
-
-		writtenConfig, err := ReadCustomConfig()
-		gomega.Expect(err).To(gomega.BeNil())
-		gomega.Expect(writtenConfig.Containers.Devices).To(gomega.BeEquivalentTo(config.Containers.Devices))
-		gomega.Expect(writtenConfig.Containers.Env).To(gomega.BeEquivalentTo(config.Containers.Env))
-		gomega.Expect(writtenConfig.Containers.Env.Attributes.Append).To(gomega.BeEquivalentTo(&boolTrue))
-	})
 	It("Default Umask", func() {
 		// Given
 		// When
 		config, err := New(nil)
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config.Containers.Umask).To(gomega.Equal("0022"))
 	})
 	It("Set Umask", func() {
@@ -391,12 +433,12 @@ var _ = Describe("Config Local", func() {
 		// When
 		config, err := NewConfig("testdata/containers_default.conf")
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config.Containers.Umask).To(gomega.Equal("0002"))
 	})
 	It("Should fail on bad Umask", func() {
 		defConf, err := defaultConfig()
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 		// Given
@@ -406,30 +448,18 @@ var _ = Describe("Config Local", func() {
 		err = defConf.Containers.Validate()
 
 		// Then
-		gomega.Expect(err).NotTo(gomega.BeNil())
-	})
-
-	It("Set Machine Enabled", func() {
-		// Given
-		config, err := New(nil)
-		gomega.Expect(err).To(gomega.BeNil())
-		gomega.Expect(config.Engine.MachineEnabled).To(gomega.Equal(false))
-		// When
-		config2, err := NewConfig("testdata/containers_default.conf")
-		// Then
-		gomega.Expect(err).To(gomega.BeNil())
-		gomega.Expect(config2.Engine.MachineEnabled).To(gomega.Equal(true))
+		gomega.Expect(err).To(gomega.HaveOccurred())
 	})
 
 	It("default netns", func() {
 		// Given
 		config, err := New(nil)
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config.Containers.NetNS).To(gomega.Equal("private"))
 		// When
 		config2, err := NewConfig("testdata/containers_default.conf")
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config2.Containers.NetNS).To(gomega.Equal("bridge"))
 	})
 
@@ -438,7 +468,7 @@ var _ = Describe("Config Local", func() {
 		path := ""
 		// When
 		config, err := NewConfig(path)
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		// Then
 		gomega.Expect(config.Secrets.Driver).To(gomega.Equal("file"))
 	})
@@ -448,7 +478,7 @@ var _ = Describe("Config Local", func() {
 		path := "testdata/containers_override.conf"
 		// When
 		config, err := NewConfig(path)
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		// Then
 		gomega.Expect(config.Secrets.Driver).To(gomega.Equal("pass"))
 		gomega.Expect(config.Secrets.Opts).To(gomega.Equal(map[string]string{
@@ -460,12 +490,12 @@ var _ = Describe("Config Local", func() {
 	It("Set machine image path", func() {
 		// Given
 		config, err := New(nil)
-		gomega.Expect(err).To(gomega.BeNil())
-		gomega.Expect(config.Machine.Image).To(gomega.Equal("testing"))
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config.Machine.Image).To(gomega.Equal(""))
 		// When
 		config2, err := NewConfig("testdata/containers_default.conf")
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		path := "https://example.com/$OS/$ARCH/foobar.ami"
 		gomega.Expect(config2.Machine.Image).To(gomega.Equal(path))
 		val := fmt.Sprintf("https://example.com/%s/%s/foobar.ami", runtime.GOOS, runtime.GOARCH)
@@ -475,60 +505,60 @@ var _ = Describe("Config Local", func() {
 	It("CompatAPIEnforceDockerHub", func() {
 		// Given
 		config, err := New(nil)
-		gomega.Expect(err).To(gomega.BeNil())
-		gomega.Expect(config.Engine.CompatAPIEnforceDockerHub).To(gomega.Equal(true))
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config.Engine.CompatAPIEnforceDockerHub).To(gomega.BeTrue())
 		// When
 		config2, err := NewConfig("testdata/containers_default.conf")
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
-		gomega.Expect(config2.Engine.CompatAPIEnforceDockerHub).To(gomega.Equal(false))
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config2.Engine.CompatAPIEnforceDockerHub).To(gomega.BeFalse())
 	})
 
 	It("ComposeProviders", func() {
 		// Given
 		config, err := New(nil)
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config.Engine.ComposeProviders.Get()).To(gomega.Equal(getDefaultComposeProviders())) // no hard-coding to work on all platforms
 		// When
 		config2, err := NewConfig("testdata/containers_default.conf")
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config2.Engine.ComposeProviders.Get()).To(gomega.Equal([]string{"/some/thing/else", "/than/before"}))
 	})
 
 	It("AddCompression", func() {
 		// Given
 		config, err := New(nil)
-		gomega.Expect(err).To(gomega.BeNil())
-		gomega.Expect(config.Engine.AddCompression.Get()).To(gomega.HaveLen(0)) // no hard-coding to work on all platforms
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config.Engine.AddCompression.Get()).To(gomega.BeEmpty()) // no hard-coding to work on all platforms
 		// When
 		config2, err := NewConfig("testdata/containers_default.conf")
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config2.Engine.AddCompression.Get()).To(gomega.Equal([]string{"zstd", "zstd:chunked"}))
 	})
 
 	It("ComposeWarningLogs", func() {
 		// Given
 		config, err := New(nil)
-		gomega.Expect(err).To(gomega.BeNil())
-		gomega.Expect(config.Engine.ComposeWarningLogs).To(gomega.Equal(true))
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config.Engine.ComposeWarningLogs).To(gomega.BeTrue())
 		// When
 		config2, err := NewConfig("testdata/containers_default.conf")
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
-		gomega.Expect(config2.Engine.ComposeWarningLogs).To(gomega.Equal(false))
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config2.Engine.ComposeWarningLogs).To(gomega.BeFalse())
 	})
 
 	It("Set machine disk", func() {
 		// Given
 		config, err := New(nil)
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config.Machine.DiskSize).To(gomega.Equal(uint64(100)))
 		// When
 		config2, err := NewConfig("testdata/containers_default.conf")
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config2.Machine.DiskSize).To(gomega.Equal(uint64(20)))
 	})
 	It("Set machine CPUs", func() {
@@ -539,23 +569,34 @@ var _ = Describe("Config Local", func() {
 		}
 
 		config, err := New(nil)
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config.Machine.CPUs).To(gomega.Equal(uint64(cpus)))
 		// When
 		config2, err := NewConfig("testdata/containers_default.conf")
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config2.Machine.CPUs).To(gomega.Equal(uint64(1)))
 	})
 	It("Set machine memory", func() {
 		// Given
 		config, err := New(nil)
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config.Machine.Memory).To(gomega.Equal(uint64(2048)))
 		// When
 		config2, err := NewConfig("testdata/containers_default.conf")
 		// Then
-		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config2.Machine.Memory).To(gomega.Equal(uint64(1024)))
 	})
+	It("Get Rosetta value", func() {
+		// Given
+		config, err := New(nil)
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config.Machine.Rosetta).To(gomega.BeTrue())
+		// When
+		config2, err := NewConfig("testdata/containers_default.conf")
+		// Then
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		gomega.Expect(config2.Machine.Rosetta).To(gomega.BeFalse())
+	})
 })
