@@ -3,7 +3,6 @@ package config
 import (
 	"bytes"
 	"fmt"
-	"io"
 	"os"
 	"runtime"
 	"sort"
@@ -25,9 +24,10 @@ var _ = Describe("Config", func() {
 			defaultConfig, err := NewConfig("")
 
 			// Then
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(defaultConfig.Containers.ApparmorProfile).To(gomega.Equal(apparmor.Profile))
 			gomega.Expect(defaultConfig.Containers.BaseHostsFile).To(gomega.Equal(""))
+			gomega.Expect(defaultConfig.Containers.InterfaceName).To(gomega.Equal(""))
 			gomega.Expect(defaultConfig.Containers.PidsLimit).To(gomega.BeEquivalentTo(2048))
 			gomega.Expect(defaultConfig.Containers.Privileged).To(gomega.BeFalse())
 			gomega.Expect(defaultConfig.Containers.ReadOnly).To(gomega.BeFalse())
@@ -37,25 +37,26 @@ var _ = Describe("Config", func() {
 			gomega.Expect(defaultConfig.NetNS()).To(gomega.BeEquivalentTo("private"))
 			gomega.Expect(defaultConfig.IPCNS()).To(gomega.BeEquivalentTo("shareable"))
 			gomega.Expect(defaultConfig.Engine.InfraImage).To(gomega.BeEquivalentTo(""))
-			if runtime.GOOS == "freebsd" {
-				gomega.Expect(defaultConfig.Engine.ImageVolumeMode).To(gomega.BeEquivalentTo("nullfs"))
-			} else {
-				gomega.Expect(defaultConfig.Engine.ImageVolumeMode).To(gomega.BeEquivalentTo("bind"))
-			}
+			gomega.Expect(defaultConfig.Engine.ImageVolumeMode).To(gomega.BeEquivalentTo("anonymous"))
 			gomega.Expect(defaultConfig.Engine.SSHConfig).To(gomega.ContainSubstring("/.ssh/config"))
 			gomega.Expect(defaultConfig.Engine.EventsContainerCreateInspectData).To(gomega.BeFalse())
 			gomega.Expect(defaultConfig.Engine.DBBackend).To(gomega.Equal(""))
 			gomega.Expect(defaultConfig.Engine.PodmanshTimeout).To(gomega.BeEquivalentTo(30))
-			gomega.Expect(defaultConfig.Engine.AddCompression.Get()).To(gomega.HaveLen(0))
+			gomega.Expect(defaultConfig.Engine.AddCompression.Get()).To(gomega.BeEmpty())
+			gomega.Expect(defaultConfig.Podmansh.Container).To(gomega.Equal("podmansh"))
+			gomega.Expect(defaultConfig.Podmansh.Shell).To(gomega.Equal("/bin/sh"))
+			gomega.Expect(defaultConfig.Podmansh.Timeout).To(gomega.BeEquivalentTo(0))
 
 			path, err := defaultConfig.ImageCopyTmpDir()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(path).To(gomega.BeEquivalentTo("/var/tmp"))
+			gomega.Expect(defaultConfig.Engine.Retry).To(gomega.BeEquivalentTo(3))
+			gomega.Expect(defaultConfig.Engine.RetryDelay).To(gomega.Equal(""))
 		})
 
 		It("should succeed with devices", func() {
 			defConf, err := defaultConfig()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 			// Given
@@ -70,12 +71,12 @@ var _ = Describe("Config", func() {
 			err = defConf.Containers.Validate()
 
 			// Then
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		})
 
 		It("should fail wrong max log size", func() {
 			defConf, err := defaultConfig()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 			// Given
@@ -85,12 +86,12 @@ var _ = Describe("Config", func() {
 			err = defConf.Validate()
 
 			// Then
-			gomega.Expect(err).NotTo(gomega.BeNil())
+			gomega.Expect(err).To(gomega.HaveOccurred())
 		})
 
 		It("should succeed with valid shm size", func() {
 			defConf, err := defaultConfig()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 			// Given
@@ -100,7 +101,7 @@ var _ = Describe("Config", func() {
 			err = defConf.Validate()
 
 			// Then
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 
 			// Given
 			defConf.Containers.ShmSize = "64m"
@@ -109,12 +110,12 @@ var _ = Describe("Config", func() {
 			err = defConf.Validate()
 
 			// Then
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		})
 
 		It("should fail wrong shm size", func() {
 			defConf, err := defaultConfig()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 			// Given
@@ -124,7 +125,7 @@ var _ = Describe("Config", func() {
 			err = defConf.Validate()
 
 			// Then
-			gomega.Expect(err).NotTo(gomega.BeNil())
+			gomega.Expect(err).To(gomega.HaveOccurred())
 		})
 
 		It("Check SELinux settings", func() {
@@ -133,12 +134,39 @@ var _ = Describe("Config", func() {
 			gomega.Expect(defaultConfig.Containers.EnableLabeling).To(gomega.Equal(selinux.GetEnabled()))
 			gomega.Expect(defaultConfig.Containers.EnableLabeledUsers).To(gomega.BeFalse())
 		})
+
+		It("Check podmansh timeout settings", func() {
+			// Note: Podmansh.Timeout must be preferred over Engine.PodmanshTimeout
+
+			// Given
+			defaultConfig, _ := NewConfig("")
+			// When
+			defaultConfig.Engine.PodmanshTimeout = 30
+			defaultConfig.Podmansh.Timeout = 0
+
+			// Then
+			gomega.Expect(defaultConfig.PodmanshTimeout()).To(gomega.Equal(uint(30)))
+
+			// When
+			defaultConfig.Engine.PodmanshTimeout = 0
+			defaultConfig.Podmansh.Timeout = 42
+
+			// Then
+			gomega.Expect(defaultConfig.PodmanshTimeout()).To(gomega.Equal(uint(42)))
+
+			// When
+			defaultConfig.Engine.PodmanshTimeout = 300
+			defaultConfig.Podmansh.Timeout = 42
+
+			// Then
+			gomega.Expect(defaultConfig.PodmanshTimeout()).To(gomega.Equal(uint(42)))
+		})
 	})
 
 	Describe("ValidateNetworkConfig", func() {
 		It("should succeed with default config", func() {
 			defConf, err := defaultConfig()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 			// Given
@@ -146,7 +174,7 @@ var _ = Describe("Config", func() {
 			err = defConf.Network.Validate()
 
 			// Then
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		})
 	})
 
@@ -158,18 +186,18 @@ var _ = Describe("Config", func() {
 image_copy_tmp_dir="storage"`
 			err := os.WriteFile(testFile, []byte(content), os.ModePerm)
 			// Then
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			defer os.Remove(testFile)
 
 			config, _ := NewConfig(testFile)
 			path, err := config.ImageCopyTmpDir()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(path).To(gomega.ContainSubstring("containers/storage/tmp"))
 			// Given we do
 			oldTMPDIR, set := os.LookupEnv("TMPDIR")
 			os.Setenv("TMPDIR", "/var/tmp/foobar")
 			path, err = config.ImageCopyTmpDir()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(path).To(gomega.BeEquivalentTo("/var/tmp/foobar"))
 			if set {
 				os.Setenv("TMPDIR", oldTMPDIR)
@@ -185,9 +213,11 @@ image_copy_tmp_dir="storage"`
 			// When
 			defaultConfig, _ := defaultConfig()
 			// prior to reading local config, shows hard coded defaults
-			gomega.Expect(defaultConfig.Containers.HTTPProxy).To(gomega.Equal(true))
+			gomega.Expect(defaultConfig.Containers.HTTPProxy).To(gomega.BeTrue())
+			gomega.Expect(defaultConfig.Engine.HealthcheckEvents).To(gomega.BeTrue())
+			gomega.Expect(defaultConfig.Containers.ContainerNameAsHostName).To(gomega.BeFalse())
 
-			err := readConfigFromFile("testdata/containers_default.conf", defaultConfig)
+			err := readConfigFromFile("testdata/containers_default.conf", defaultConfig, false)
 
 			crunWasm := "crun-wasm"
 			PlatformToOCIRuntimeMap := map[string]string{
@@ -223,6 +253,14 @@ image_copy_tmp_dir="storage"`
 					"/usr/bin/crun",
 					"/usr/local/bin/crun",
 				},
+				"crun-vm": {
+					"/usr/bin/crun-vm",
+					"/usr/local/bin/crun-vm",
+					"/usr/local/sbin/crun-vm",
+					"/sbin/crun-vm",
+					"/bin/crun-vm",
+					"/run/current-system/sw/bin/crun-vm",
+				},
 				"crun-wasm": {
 					"/usr/bin/crun-wasm",
 					"/usr/sbin/crun-wasm",
@@ -283,8 +321,9 @@ image_copy_tmp_dir="storage"`
 			}
 
 			// Then
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(defaultConfig.Engine.CgroupManager).To(gomega.Equal("systemd"))
+			gomega.Expect(defaultConfig.Containers.ContainerNameAsHostName).To(gomega.BeTrue())
 			gomega.Expect(defaultConfig.Containers.Env.Get()).To(gomega.BeEquivalentTo(envs))
 			gomega.Expect(defaultConfig.Containers.Mounts.Get()).To(gomega.BeEquivalentTo(mounts))
 			gomega.Expect(defaultConfig.Containers.PidsLimit).To(gomega.BeEquivalentTo(2048))
@@ -293,21 +332,27 @@ image_copy_tmp_dir="storage"`
 			gomega.Expect(defaultConfig.Engine.NumLocks).To(gomega.BeEquivalentTo(2048))
 			gomega.Expect(defaultConfig.Engine.OCIRuntimes).To(gomega.Equal(OCIRuntimeMap))
 			gomega.Expect(defaultConfig.Engine.PlatformToOCIRuntime).To(gomega.Equal(PlatformToOCIRuntimeMap))
-			gomega.Expect(defaultConfig.Containers.HTTPProxy).To(gomega.Equal(false))
-			gomega.Expect(defaultConfig.Engine.NetworkCmdOptions.Get()).To(gomega.HaveLen(0))
+			gomega.Expect(defaultConfig.Containers.HTTPProxy).To(gomega.BeFalse())
+			gomega.Expect(defaultConfig.Engine.NetworkCmdOptions.Get()).To(gomega.BeEmpty())
 			gomega.Expect(defaultConfig.Engine.HelperBinariesDir.Get()).To(gomega.Equal(helperDirs))
 			gomega.Expect(defaultConfig.Engine.ServiceTimeout).To(gomega.BeEquivalentTo(300))
-			gomega.Expect(defaultConfig.Engine.InfraImage).To(gomega.BeEquivalentTo("k8s.gcr.io/pause:3.4.1"))
-			gomega.Expect(defaultConfig.Machine.Volumes.Get()).To(gomega.BeEquivalentTo(volumes))
+			gomega.Expect(defaultConfig.Engine.InfraImage).To(gomega.BeEquivalentTo("registry.k8s.io/pause:3.4.1"))
 			gomega.Expect(defaultConfig.Engine.PodmanshTimeout).To(gomega.BeEquivalentTo(300))
+			gomega.Expect(defaultConfig.Machine.Volumes.Get()).To(gomega.BeEquivalentTo(volumes))
+			gomega.Expect(defaultConfig.Podmansh.Timeout).To(gomega.BeEquivalentTo(42))
+			gomega.Expect(defaultConfig.Podmansh.Shell).To(gomega.Equal("/bin/zsh"))
+			gomega.Expect(defaultConfig.Podmansh.Container).To(gomega.BeEquivalentTo("podmansh-1"))
+			gomega.Expect(defaultConfig.Engine.HealthcheckEvents).To(gomega.BeFalse())
 			newV, err := defaultConfig.MachineVolumes()
 			if newVolumes[0] == ":" {
 				// $HOME is not set
 				gomega.Expect(err).To(gomega.HaveOccurred())
 			} else {
-				gomega.Expect(err).To(gomega.BeNil())
+				gomega.Expect(err).ToNot(gomega.HaveOccurred())
 				gomega.Expect(newV).To(gomega.BeEquivalentTo(newVolumes))
 			}
+			gomega.Expect(defaultConfig.Engine.Retry).To(gomega.BeEquivalentTo(5))
+			gomega.Expect(defaultConfig.Engine.RetryDelay).To(gomega.Equal("10s"))
 		})
 
 		It("test GetDefaultEnvEx", func() {
@@ -342,30 +387,30 @@ image_copy_tmp_dir="storage"`
 			// Given
 			// When
 			conf := Config{}
-			err := readConfigFromFile("testdata/containers_comment.conf", &conf)
+			err := readConfigFromFile("testdata/containers_comment.conf", &conf, false)
 
 			// Then
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		})
 
 		It("should fail when file does not exist", func() {
 			// Given
 			// When
 			conf := Config{}
-			err := readConfigFromFile("/invalid/file", &conf)
+			err := readConfigFromFile("/invalid/file", &conf, false)
 
 			// Then
-			gomega.Expect(err).NotTo(gomega.BeNil())
+			gomega.Expect(err).To(gomega.HaveOccurred())
 		})
 
 		It("should fail when toml decode fails", func() {
 			// Given
 			// When
 			conf := Config{}
-			err := readConfigFromFile("config.go", &conf)
+			err := readConfigFromFile("config.go", &conf, false)
 
 			// Then
-			gomega.Expect(err).NotTo(gomega.BeNil())
+			gomega.Expect(err).To(gomega.HaveOccurred())
 		})
 	})
 
@@ -413,18 +458,18 @@ image_copy_tmp_dir="storage"`
 			}
 
 			// Given we do
-			oldContainersConf, envSet := os.LookupEnv("CONTAINERS_CONF")
-			os.Setenv("CONTAINERS_CONF", "/dev/null")
+			oldContainersConf, envSet := os.LookupEnv(containersConfEnv)
+			os.Setenv(containersConfEnv, "/dev/null")
 			// When
 			config, err := NewConfig("")
 			// Undo that
 			if envSet {
-				os.Setenv("CONTAINERS_CONF", oldContainersConf)
+				os.Setenv(containersConfEnv, oldContainersConf)
 			} else {
-				os.Unsetenv("CONTAINERS_CONF")
+				os.Unsetenv(containersConfEnv)
 			}
 			// Then
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(config.Containers.ApparmorProfile).To(gomega.Equal(apparmor.Profile))
 			gomega.Expect(config.Containers.PidsLimit).To(gomega.BeEquivalentTo(2048))
 			gomega.Expect(config.Containers.Env.Get()).To(gomega.BeEquivalentTo(envs))
@@ -433,7 +478,7 @@ image_copy_tmp_dir="storage"`
 			gomega.Expect(config.Network.NetavarkPluginDirs.Get()).To(gomega.Equal(DefaultNetavarkPluginDirs))
 			gomega.Expect(config.Engine.NumLocks).To(gomega.BeEquivalentTo(2048))
 			gomega.Expect(config.Engine.OCIRuntimes["runc"]).To(gomega.Equal(OCIRuntimeMap["runc"]))
-			gomega.Expect(config.Containers.CgroupConf.Get()).To(gomega.HaveLen(0))
+			gomega.Expect(config.Containers.CgroupConf.Get()).To(gomega.BeEmpty())
 
 			caps, _ := config.Capabilities("", nil, nil)
 			gomega.Expect(caps).Should(gomega.Equal(defCaps))
@@ -464,7 +509,7 @@ image_copy_tmp_dir="storage"`
 			cgroupConf := []string{
 				"memory.high=1073741824",
 			}
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(config.Containers.ApparmorProfile).To(gomega.Equal("container-default"))
 			gomega.Expect(config.Containers.PidsLimit).To(gomega.BeEquivalentTo(2048))
 			gomega.Expect(config.Containers.BaseHostsFile).To(gomega.BeEquivalentTo("/etc/hosts2"))
@@ -480,15 +525,15 @@ image_copy_tmp_dir="storage"`
 
 		It("contents of passed-in file should override others", func() {
 			// Given we do
-			oldContainersConf, envSet := os.LookupEnv("CONTAINERS_CONF")
-			os.Setenv("CONTAINERS_CONF", "containers.conf")
+			oldContainersConf, envSet := os.LookupEnv(containersConfEnv)
+			os.Setenv(containersConfEnv, "containers.conf")
 			// When
 			config, err := NewConfig("testdata/containers_override.conf")
 			// Undo that
 			if envSet {
-				os.Setenv("CONTAINERS_CONF", oldContainersConf)
+				os.Setenv(containersConfEnv, oldContainersConf)
 			} else {
-				os.Unsetenv("CONTAINERS_CONF")
+				os.Unsetenv(containersConfEnv)
 			}
 
 			crunWasm := "crun-wasm"
@@ -504,7 +549,7 @@ image_copy_tmp_dir="storage"`
 			gomega.Expect(runtimes).To(gomega.Equal(crunWasm))
 
 			// Then
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(config).ToNot(gomega.BeNil())
 			gomega.Expect(config.Containers.ApparmorProfile).To(gomega.Equal("overridden-default"))
 			gomega.Expect(config.Containers.LogDriver).To(gomega.Equal("journald"))
@@ -519,7 +564,7 @@ image_copy_tmp_dir="storage"`
 			gomega.Expect(config.Engine.EventsLogFilePath).To(gomega.BeEquivalentTo("/tmp/events.log"))
 			gomega.Expect(config.Engine.EventsContainerCreateInspectData).To(gomega.BeTrue())
 			path, err := config.ImageCopyTmpDir()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(path).To(gomega.BeEquivalentTo("/tmp/foobar"))
 			gomega.Expect(uint64(config.Engine.EventsLogFileMaxSize)).To(gomega.Equal(uint64(500)))
 			gomega.Expect(config.Engine.PodExitPolicy).To(gomega.BeEquivalentTo(PodExitPolicyStop))
@@ -530,7 +575,7 @@ image_copy_tmp_dir="storage"`
 			// When
 			config, err := NewConfig("testdata/containers_invalid.conf")
 			// Then
-			gomega.Expect(err).ToNot(gomega.BeNil())
+			gomega.Expect(err).To(gomega.HaveOccurred())
 			gomega.Expect(config).To(gomega.BeNil())
 		})
 
@@ -542,10 +587,10 @@ image_copy_tmp_dir="storage"`
 			// When
 			config, err := NewConfig("")
 			// Then
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			var addcaps, dropcaps []string
 			caps, err := config.Capabilities("0", addcaps, dropcaps)
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			sort.Strings(caps)
 			defaultCaps := config.Containers.DefaultCapabilities.Get()
 			sort.Strings(defaultCaps)
@@ -554,16 +599,16 @@ image_copy_tmp_dir="storage"`
 			// Add all caps
 			addcaps = []string{"all"}
 			caps, err = config.Capabilities("root", addcaps, dropcaps)
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			sort.Strings(caps)
 			boundingSet, err := capabilities.BoundingSet()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(caps).To(gomega.BeEquivalentTo(boundingSet))
 
 			// Drop all caps
 			dropcaps = []string{"all"}
 			caps, err = config.Capabilities("", boundingSet, dropcaps)
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			sort.Strings(caps)
 			gomega.Expect(caps).ToNot(gomega.BeEquivalentTo([]string{}))
 
@@ -585,61 +630,61 @@ image_copy_tmp_dir="storage"`
 			addcaps = []string{"CAP_NET_ADMIN", "CAP_SYS_ADMIN"}
 			dropcaps = []string{"CAP_FOWNER", "CAP_CHOWN"}
 			caps, err = config.Capabilities("", addcaps, dropcaps)
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			sort.Strings(caps)
 			gomega.Expect(caps).To(gomega.BeEquivalentTo(expectedCaps))
 
 			addcaps = []string{"NET_ADMIN", "cap_sys_admin"}
 			dropcaps = []string{"FOWNER", "chown"}
 			caps, err = config.Capabilities("", addcaps, dropcaps)
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			sort.Strings(caps)
 			gomega.Expect(caps).To(gomega.BeEquivalentTo(expectedCaps))
 
 			expectedCaps = []string{"CAP_NET_ADMIN", "CAP_SYS_ADMIN"}
 			caps, err = config.Capabilities("notroot", addcaps, dropcaps)
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			sort.Strings(caps)
 			gomega.Expect(caps).To(gomega.BeEquivalentTo(expectedCaps))
 		})
 
 		It("should succeed with default pull_policy", func() {
 			defConf, err := defaultConfig()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 			err = defConf.Engine.Validate()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(defConf.Engine.PullPolicy).To(gomega.Equal("missing"))
 
 			defConf.Engine.PullPolicy = DefaultPullPolicy
 			err = defConf.Engine.Validate()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		})
 
 		It("should succeed case-insensitive", func() {
 			defConf, err := defaultConfig()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 			defConf.Engine.PullPolicy = "NeVer"
 			err = defConf.Engine.Validate()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		})
 
 		It("should fail with invalid pull_policy", func() {
 			defConf, err := defaultConfig()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 			defConf.Engine.PullPolicy = "invalidPullPolicy"
 			err = defConf.Engine.Validate()
-			gomega.Expect(err).ToNot(gomega.BeNil())
+			gomega.Expect(err).To(gomega.HaveOccurred())
 		})
 
 		It("should fail with invalid database_backend", func() {
 			defConf, err := defaultConfig()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(defConf).NotTo(gomega.BeNil())
 
 			defConf.Engine.DBBackend = "blah"
@@ -655,55 +700,20 @@ image_copy_tmp_dir="storage"`
 		}{}
 
 		BeforeEach(func() {
-			ConfPath.Value, ConfPath.IsSet = os.LookupEnv("CONTAINERS_CONF")
+			ConfPath.Value, ConfPath.IsSet = os.LookupEnv(containersConfEnv)
 			conf, _ := os.CreateTemp("", "containersconf")
-			os.Setenv("CONTAINERS_CONF", conf.Name())
+			os.Setenv(containersConfEnv, conf.Name())
 		})
 
 		AfterEach(func() {
-			os.Remove(os.Getenv("CONTAINERS_CONF"))
+			os.Remove(os.Getenv(containersConfEnv))
 			if ConfPath.IsSet {
-				os.Setenv("CONTAINERS_CONF", ConfPath.Value)
+				os.Setenv(containersConfEnv, ConfPath.Value)
 			} else {
-				os.Unsetenv("CONTAINERS_CONF")
+				os.Unsetenv(containersConfEnv)
 			}
 		})
 
-		It("succeed to set and read", func() {
-			cfg, err := ReadCustomConfig()
-			gomega.Expect(err).ShouldNot(gomega.HaveOccurred())
-
-			cfg.Engine.ActiveService = "QA"
-			cfg.Engine.ServiceDestinations = map[string]Destination{
-				"QA": {
-					URI:      "https://qa/run/podman/podman.sock",
-					Identity: "/.ssh/id_rsa",
-				},
-			}
-			err = cfg.Write()
-			gomega.Expect(err).ShouldNot(gomega.HaveOccurred())
-
-			// test that we do not write zero values to the file
-			path, err := customConfigFile()
-			gomega.Expect(err).ShouldNot(gomega.HaveOccurred())
-			f, err := os.Open(path)
-			gomega.Expect(err).ShouldNot(gomega.HaveOccurred())
-			data, err := io.ReadAll(f)
-			gomega.Expect(err).ShouldNot(gomega.HaveOccurred())
-			gomega.Expect(string(data)).ShouldNot(gomega.ContainSubstring("cpus"))
-			gomega.Expect(string(data)).ShouldNot(gomega.ContainSubstring("disk_size"))
-			gomega.Expect(string(data)).ShouldNot(gomega.ContainSubstring("memory"))
-
-			cfg, err = ReadCustomConfig()
-			gomega.Expect(err).ShouldNot(gomega.HaveOccurred())
-
-			gomega.Expect(cfg.Engine.ActiveService, "QA")
-			gomega.Expect(cfg.Engine.ServiceDestinations["QA"].URI,
-				"https://qa/run/podman/podman.sock")
-			gomega.Expect(cfg.Engine.ServiceDestinations["QA"].Identity,
-				"/.ssh/id_rsa")
-		})
-
 		It("test addConfigs", func() {
 			tmpFilePath := func(dir, prefix string) string {
 				file, err := os.CreateTemp(dir, prefix)
@@ -751,8 +761,8 @@ image_copy_tmp_dir="storage"`
 			content := bytes.NewBufferString("")
 			logrus.SetOutput(content)
 			logrus.SetLevel(logrus.DebugLevel)
-			err := readConfigFromFile("testdata/containers_broken.conf", &conf)
-			gomega.Expect(err).To(gomega.BeNil())
+			err := readConfigFromFile("testdata/containers_broken.conf", &conf, false)
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(conf.Containers.NetNS).To(gomega.Equal("bridge"))
 			gomega.Expect(conf.Containers.Umask).To(gomega.Equal("0002"))
 			gomega.Expect(content).To(gomega.ContainSubstring("Failed to decode the keys [\\\"foo\\\" \\\"containers.image_default_transport\\\"] from \\\"testdata/containers_broken.conf\\\""))
@@ -763,86 +773,25 @@ image_copy_tmp_dir="storage"`
 			conf := Config{}
 			content := bytes.NewBufferString("")
 			logrus.SetOutput(content)
-			err := readConfigFromFile("containers.conf", &conf)
-			gomega.Expect(err).To(gomega.BeNil())
+			err := readConfigFromFile("containers.conf", &conf, false)
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			gomega.Expect(content.String()).To(gomega.Equal(""))
 			logrus.SetOutput(os.Stderr)
 		})
 	})
 
-	Describe("Farms", func() {
-		ConfPath := struct {
-			Value string
-			IsSet bool
-		}{}
-
-		BeforeEach(func() {
-			ConfPath.Value, ConfPath.IsSet = os.LookupEnv("CONTAINERS_CONF")
-			conf, _ := os.CreateTemp("", "containersconf")
-			os.Setenv("CONTAINERS_CONF", conf.Name())
-		})
-
-		AfterEach(func() {
-			os.Remove(os.Getenv("CONTAINERS_CONF"))
-			if ConfPath.IsSet {
-				os.Setenv("CONTAINERS_CONF", ConfPath.Value)
-			} else {
-				os.Unsetenv("CONTAINERS_CONF")
-			}
-		})
-
-		It("succeed to set and read", func() {
-			cfg, err := ReadCustomConfig()
-			gomega.Expect(err).ShouldNot(gomega.HaveOccurred())
-
-			cfg.Engine.ActiveService = "QA"
-			cfg.Engine.ServiceDestinations = map[string]Destination{
-				"QA": {
-					URI:      "https://qa/run/podman/podman.sock",
-					Identity: "/.ssh/id_rsa",
-				},
-			}
-			err = cfg.Write()
-			gomega.Expect(err).ShouldNot(gomega.HaveOccurred())
-
-			// test that connections were written correctly
-			cfg, err = ReadCustomConfig()
-			gomega.Expect(err).ShouldNot(gomega.HaveOccurred())
-			gomega.Expect(cfg.Engine.ActiveService, "QA")
-			gomega.Expect(cfg.Engine.ServiceDestinations["QA"].URI,
-				"https://qa/run/podman/podman.sock")
-			gomega.Expect(cfg.Engine.ServiceDestinations["QA"].Identity,
-				"/.ssh/id_rsa")
-
-			// Create farm
-			cfg.Farms.Default = "Farm-1"
-			cfg.Farms.List = map[string][]string{
-				"Farm-1": {"QA"},
-			}
-			err = cfg.Write()
-			gomega.Expect(err).ShouldNot(gomega.HaveOccurred())
-
-			cfg, err = ReadCustomConfig()
-			gomega.Expect(err).ShouldNot(gomega.HaveOccurred())
-
-			gomega.Expect(cfg.Farms.Default, "Farm-1")
-			gomega.Expect(cfg.Farms.List["Farm-1"],
-				"QA")
-		})
-	})
-
 	Describe("Reload", func() {
 		It("test new config from reload", func() {
 			// Default configuration
 			defaultTestFile := "testdata/containers_default.conf"
-			oldEnv, set := os.LookupEnv("CONTAINERS_CONF")
-			os.Setenv("CONTAINERS_CONF", defaultTestFile)
+			oldEnv, set := os.LookupEnv(containersConfEnv)
+			os.Setenv(containersConfEnv, defaultTestFile)
 			cfg, err := Default()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			if set {
-				os.Setenv("CONTAINERS_CONF", oldEnv)
+				os.Setenv(containersConfEnv, oldEnv)
 			} else {
-				os.Unsetenv("CONTAINERS_CONF")
+				os.Unsetenv(containersConfEnv)
 			}
 
 			// Reload from new configuration file
@@ -851,17 +800,17 @@ image_copy_tmp_dir="storage"`
 env=["foo=bar"]`
 			err = os.WriteFile(testFile, []byte(content), os.ModePerm)
 			defer os.Remove(testFile)
-			gomega.Expect(err).To(gomega.BeNil())
-			oldEnv, set = os.LookupEnv("CONTAINERS_CONF")
-			os.Setenv("CONTAINERS_CONF", testFile)
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
+			oldEnv, set = os.LookupEnv(containersConfEnv)
+			os.Setenv(containersConfEnv, testFile)
 			_, err = Reload()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			newCfg, err := Default()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 			if set {
-				os.Setenv("CONTAINERS_CONF", oldEnv)
+				os.Setenv(containersConfEnv, oldEnv)
 			} else {
-				os.Unsetenv("CONTAINERS_CONF")
+				os.Unsetenv(containersConfEnv)
 			}
 
 			expectOldEnv := []string{"PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin"}
@@ -870,30 +819,10 @@ env=["foo=bar"]`
 			gomega.Expect(newCfg.Containers.Env.Get()).To(gomega.Equal(expectNewEnv))
 			// Reload change back to default global configuration
 			_, err = Reload()
-			gomega.Expect(err).To(gomega.BeNil())
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		})
 	})
 
-	It("write default config should be empty", func() {
-		defer os.Unsetenv("CONTAINERS_CONF")
-		os.Setenv("CONTAINERS_CONF", "/dev/null")
-		conf, err := ReadCustomConfig()
-		gomega.Expect(err).ToNot(gomega.HaveOccurred())
-
-		f, err := os.CreateTemp("", "container-common-test")
-		gomega.Expect(err).ToNot(gomega.HaveOccurred())
-		defer f.Close()
-		defer os.Remove(f.Name())
-		os.Setenv("CONTAINERS_CONF", f.Name())
-		err = conf.Write()
-		gomega.Expect(err).ToNot(gomega.HaveOccurred())
-		b, err := os.ReadFile(f.Name())
-		gomega.Expect(err).ToNot(gomega.HaveOccurred())
-		// config should only contain empty stanzas
-		gomega.Expect(string(b)).To(gomega.
-			Equal("[containers]\n\n[engine]\n\n[machine]\n\n[network]\n\n[secrets]\n\n[configmaps]\n\n[farms]\n"))
-	})
-
 	It("validate ImageVolumeMode", func() {
 		for _, mode := range append(validImageVolumeModes, "") {
 			err := ValidateImageVolumeMode(mode)
@@ -911,12 +840,85 @@ env=["foo=bar"]`
 		gomega.Expect(config.Containers.ApparmorProfile).To(gomega.Equal("overridden-default"))
 
 		// Make sure that _OVERRIDE is loaded even when CONTAINERS_CONF is set.
-		os.Setenv("CONTAINERS_CONF", "testdata/containers_default.conf")
-		defer os.Unsetenv("CONTAINERS_CONF")
+		os.Setenv(containersConfEnv, "testdata/containers_default.conf")
+		defer os.Unsetenv(containersConfEnv)
 		config, err = NewConfig("")
 		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		gomega.Expect(config.Containers.ApparmorProfile).To(gomega.Equal("overridden-default"))
 		gomega.Expect(config.Containers.BaseHostsFile).To(gomega.Equal("/etc/hosts2"))
 		gomega.Expect(config.Containers.EnableLabeledUsers).To(gomega.BeTrue())
 	})
+
+	It("ParsePullPolicy", func() {
+		for _, test := range []struct {
+			value  string
+			policy PullPolicy
+			fail   bool
+		}{
+			{
+				value:  "always",
+				policy: PullPolicyAlways,
+			},
+			{
+				value:  "alWays",
+				policy: PullPolicyAlways,
+			},
+			{
+				value:  "ALWAYS",
+				policy: PullPolicyAlways,
+			},
+			{
+				value:  "never",
+				policy: PullPolicyNever,
+			},
+			{
+				value:  "NEVER",
+				policy: PullPolicyNever,
+			},
+			{
+				value:  "newer",
+				policy: PullPolicyNewer,
+			},
+			{
+				value:  "ifnewer",
+				policy: PullPolicyNewer,
+			},
+			{
+				value:  "NEWER",
+				policy: PullPolicyNewer,
+			},
+			{
+				value:  "",
+				policy: PullPolicyMissing,
+			},
+			{
+				value:  "missing",
+				policy: PullPolicyMissing,
+			},
+			{
+				value:  "MISSING",
+				policy: PullPolicyMissing,
+			},
+			{
+				value:  "IFMISSING",
+				policy: PullPolicyMissing,
+			},
+			{
+				value:  "ifnotpresent",
+				policy: PullPolicyMissing,
+			},
+			{
+				value: "bogus",
+				fail:  true,
+			},
+		} {
+			p, err := ParsePullPolicy(test.value)
+			if test.fail {
+				gomega.Expect(err.Error()).To(gomega.Equal(fmt.Sprintf("unsupported pull policy %q", test.value)))
+			} else {
+				gomega.Expect(err).ToNot(gomega.HaveOccurred())
+				gomega.Expect(p).To(gomega.Equal(test.policy))
+			}
+		}
+	})
 })
