@@ -10,6 +10,7 @@ import (
 	digest "github.com/opencontainers/go-digest"
 	v1 "github.com/opencontainers/image-spec/specs-go/v1"
 	"github.com/stretchr/testify/assert"
+	"golang.org/x/exp/maps"
 )
 
 const (
@@ -85,14 +86,16 @@ func TestAddInstance(t *testing.T) {
 		if err != nil {
 			t.Fatalf("error parsing %s: %v", version, err)
 		}
-		if err = list.AddInstance(manifestDigest, int64(len(manifestBytes)), manifestType, "linux", "amd64", "", nil, "", nil, nil); err != nil {
+		annotations := []string{"A=B", "C=D"}
+		expectedAnnotations := map[string]string{"A": "B", "C": "D"}
+		if err = list.AddInstance(manifestDigest, int64(len(manifestBytes)), manifestType, "linux", "amd64", "", nil, "", nil, annotations); err != nil {
 			t.Fatalf("adding an instance failed in %s: %v", version, err)
 		}
 		if d, err := list.findDocker(manifestDigest); d == nil || err != nil {
 			t.Fatalf("adding an instance failed in %s: %v", version, err)
 		}
-		if o, err := list.findOCIv1(manifestDigest); o == nil || err != nil {
-			t.Fatalf("adding an instance failed in %s: %v", version, err)
+		if o, err := list.findOCIv1(manifestDigest); o == nil || err != nil || !maps.Equal(o.Annotations, expectedAnnotations) {
+			t.Fatalf("adding an instance failed in %s (annotations=%#v): %v", version, o.Annotations, err)
 		}
 
 		if list, err = FromBlob(bytes); err != nil {
@@ -206,7 +209,7 @@ func testStringSlice(t *testing.T, values [][]string, set func(List, digest.Dige
 	}
 }
 
-func testMap(t *testing.T, values []map[string]string, set func(List, *digest.Digest, map[string]string) error, clear func(List, *digest.Digest) error, get func(List, *digest.Digest) (map[string]string, error)) {
+func testMap(t *testing.T, values []map[string]string, set func(List, *digest.Digest, map[string]string) error, clearFunc func(List, *digest.Digest) error, get func(List, *digest.Digest) (map[string]string, error)) {
 	bytes, err := os.ReadFile(ociFixture)
 	if err != nil {
 		t.Fatalf("error loading blob: %v", err)
@@ -218,7 +221,7 @@ func testMap(t *testing.T, values []map[string]string, set func(List, *digest.Di
 	instance := expectedInstance
 	for _, instanceDigest := range []*digest.Digest{nil, &instance} {
 		for _, testMap := range values {
-			if err = clear(list, instanceDigest); err != nil {
+			if err = clearFunc(list, instanceDigest); err != nil {
 				t.Fatalf("error clearing %v: %v", testMap, err)
 			}
 			if err = set(list, instanceDigest, testMap); err != nil {
@@ -244,7 +247,7 @@ func testMap(t *testing.T, values []map[string]string, set func(List, *digest.Di
 					t.Fatalf("expected map value %q=%q, got %q", k, v, values[k])
 				}
 			}
-			if err = clear(list, instanceDigest); err != nil {
+			if err = clearFunc(list, instanceDigest); err != nil {
 				t.Fatalf("error clearing %v: %v", testMap, err)
 			}
 			values, err = get(list, instanceDigest)
